@@ -42,11 +42,16 @@ public:
     virtual ~ChGL();
     void setMainWindow(QWidget * parent){
     chparent=parent;
-    }
-    bool on;
+    }    
+    QTimer *idl;//! idle rotation timer
+    QTimer *idl_end;//! idle rotation timer
+    bool on;    
+    bool habzutun;
     int ww,//!<Window with
 	wh,//!<Window height
-	minus;//!<for streo mode swiches right and left eye view
+	minus;//!<for streo mode swiches right and left eye view    
+    int SDM_Limit; //!< if the number of atoms in the au exceeds this limit shortest distance is not computed automatically default 350
+    int retinafktr;
     int stereo_mode;//!< intager value of the current stereo mode
     int objCnt;//!< number of visible atoms + q-peaks
     int ImeanThisAtom;//!< atom index for context menu. 
@@ -62,7 +67,7 @@ public:
     QVector< QVector< float > > fNormals;
     double lintrans;//!<degree of thansparency for the maps 0-1. 0 is transparent.
     double linwidth;//!<linewidth of the meshes.
-
+    double contMin,contMax;
     QColor fopc;//!< Fo positive color
     QColor fomc;//!< Fo negative color
     QColor dipc;//!< Fo-Fc positive color
@@ -102,6 +107,7 @@ public:
 	    *invSelection,//!< QAction invert selection
         *cntrPlot,    
         *nocntrPlot,
+        *rainbowPlot,
         *hideBeLo,//!< hide/show  BEDE and LONE objects
         *useTextureLabels,//!< alternative to Qt renderText render Labels on BillBoard textures
         *shortLabels,//!< Labels without residue number or symmery flag are considered short
@@ -123,14 +129,27 @@ public:
     QAction *foact, //!< QAction toggling Fobs maps.
 	    *fofcact;//!< QAction toggling Fobs-Fcalc maps.
     int rotze;//!< if not -1 the index of an atom in the rotation center.
-    QToolButton    *invertMouseZoom;//!< inverts the mouse direction that zoom on right click.
-    QCheckBox      *lighting,//!< enable lighting on the electron density. 
-                   *niceTrans,//!< draw 6 perspectives for each surface to improve transparent visualization. 
-                   *fillMap;//!< draw maps in filled style.
+    QToolButton *invertMouseZoom;//!< inverts the mouse direction that zoom on right click.
+    QCheckBox   *lighting;//!< enable lighting on the electron density. 
+    QCheckBox   *niceTrans;//!< draw 6 perspectives for each surface to improve transparent visualization. 
+    QCheckBox   *fillMap;//!< draw maps in filled style.
     QToolButton *rCenter;//!< resets the rotation center
     V3 altemitte;//!<rotation center position
     V3 altcenter;
+    bool altpivot;
+    QComboBox *pivot1cb;
+    QComboBox *pivot2cb;
+    QDoubleSpinBox *axx;
+    QDoubleSpinBox *axy;
+    QDoubleSpinBox *axz;
+    QCheckBox *manualAx;
+    QLabel *whyNotSplit;
 //    void initLists();
+    bool canSplitRotate();
+    QSpinBox *angle1;
+    QSpinBox *angle2;
+    void farbverlauf(double wrt, double min, double max);
+    QColor farbverlaufQC(double wrt, double min, double max);
     void zoom(double speed);
     bool isFO(){return drawFO;}//!< if Fo map is visible true is returned.
     bool isDF(){return drawDF;}//!< if Fo-Fc map is visible true is returned.
@@ -166,11 +185,14 @@ signals:
     void bigmessage(const QString &);//!< passes HTML strings to the info window.
     void jumpit(int index);//!<An atom has ben left clicked: cursor jump on it.
     void selectionChanged();
+    void movedByUser();
     void diffscroll(int numsteps,int diff);//!< to change the iso value of the Fo- or Fo-Fc maps
     void neuemitte(V3 mitte);//!< the rotation center has changet to mitte.
     void inimibas();//!< tells FourXle to initialize the GL display lists.
     void qpfoci(double height);//!< when a mouse hovers a Q-Peak the height is emitted to the Q-Peak Legend.
     void insertDFIX(double value, double esd, QList<MyAtom> selected, QString resiSpec); //!< Insert DFIX restrain to the ins file
+    void bindthem();
+    void splitable(bool ok);
     void insertDANG(double value, double esd, QList<MyAtom> selected, QString resiSpec); //!< Insert DANG restrain to the ins file
     void insertFLAT(double esd, QList<MyAtom> selected, QString resiSpec); //!< Insert FLAT restrain to the ins file
     void insertEXYZ(QList<MyAtom> selected); //!< Insert EXYZ restrain to the ins file
@@ -182,12 +204,18 @@ signals:
     void insertRIGU(double esd1, double esd2, QList<MyAtom> selected, QString resiSpec); //!< Insert DELU restrain to the ins file
     void insertCHIV(double Vol, double esd1, QList<MyAtom> selected, QString resiSpec); //!< Insert CHIV restrain to the ins file
     void insertANIS(QList<MyAtom> selected); //!< Insert ANIS instruction for selected atoms
+    void pivot1Changed(int i);
+    void pivot2Changed(int i);
 public slots:
+    void sdm();
+    void rotateIdle();
     void along001(); 
     void anaglyphRedCyan();
     void changeBColor();
     void changeEnviRange();
     void changeTColor();
+    void changePivot1(int i){pivot=i;splitRotate();emit splitable(canSplitRotate()); }
+    void changePivot2(int i){pivot2=i;splitRotate();emit splitable(canSplitRotate());}
     void clearEnvi();
 //    void clearLists();
     void connectSelection();
@@ -197,6 +225,7 @@ public slots:
     void disSelection();
     void envi();
     void expand();
+    void fertig(){habzutun=false;updateGL();printf("map veritces ready!\n");}
     void hardwareStereo();
     void hideHydrogens();
     void hideNonSelected();
@@ -211,6 +240,7 @@ public slots:
     void invertSelection();
     void invertHidden();//!< Toggle visibility of atoms etc
     void Listen();
+    void singleBondDistance();
     void loadOrientation();
     void loadOrientation(QString fn);
     void nostereo();
@@ -227,6 +257,7 @@ public slots:
     void setAtom(bool b);
     void setBGGradient(bool b);
     void setBond(bool b);
+    void setDepthCueing(bool b);
     void setHBond(bool b);
     void setLabel(bool b);
     void setMSAA(bool b);
@@ -245,6 +276,7 @@ public slots:
     void setViewAngle(double ang);
     void showHidden();
     void showMatrix();
+    void splitRotate();
     void toogleWithSymmetry(bool b);
     void zoomOut();
     void unsetTube(bool b){
@@ -282,13 +314,19 @@ protected:
    void wheelEvent(QWheelEvent *event);  
 private:
   QWidget *chparent; 
+  inline void __RotateCS( double c, double s, double& X, double& Y ) ;
+  void glTranslateL( const double dx, const double dy, const double dz );
+  void glRotateL( const double dang, const double x, const double y, const double z );
+  void findPivot();  
+  QList<int> seat;//selected atoms indices for splitrotation
+  int pivot,pivot2;
   int ppp,pp,p;//there is no need this should longer GLuint 26.02.2020
 #if (QT_VERSION >= 0x040600) && (defined (Q_WS_MAC) || defined(Q_OS_MAC))
         bool gestureEvent(QGestureEvent *event);
         void pinchTriggered(QPinchGesture*);
         void swipeTriggered(QSwipeGesture*);
 #endif
-        bool mouseOverInteraction,atomsClickable,tubes,bggradient;
+        bool mouseOverInteraction,atomsClickable,tubes,bggradient,depthcueing;
         bool drawAx,drawUc,drawAt,drawADP,drawBo,drawLa,drawHb,drawFO,drawDF, warLabel;
         int imFokus,afok;
         void draw();
@@ -300,6 +338,7 @@ private:
         double labScal;
         QList<QImage> labelTextures;
         QList<QImage> extraTextures;
+        QList<QImage> enviTextures;
         int withsymm;
         QPoint lastPos;
         QStringList resis();
