@@ -45,15 +45,20 @@
 #include "shx_helper.h"
 #include "window.h"
 #include "dsrgui.h"
+#include "deprecation.h"
+#include "partcolor.h"
 //#include "chgl.h"
 
 CodeEditor::CodeEditor(QWidget *parent) : QPlainTextEdit(parent), c(0){
   lineNumberArea = new LineNumberArea(this);
   lineNumberArea->setObjectName("lineNumberArea");
+  lineNumberArea->setMouseTracking(true);
   afixHighlightArea = new AfixHighlightArea(this);
   afixHighlightArea->setObjectName("afixHighlightArea");
+  afixHighlightArea->setMouseTracking(true);
   setMouseTracking(true);
   midCursorpos=0;
+  dark=false;
   //setTabChangesFocus(true);
   highlighter = new Highlighter(document());
   connect(this, SIGNAL(blockCountChanged(int)), this, SLOT(updateLineNumberAreaWidth(int)));
@@ -71,15 +76,15 @@ CodeEditor::CodeEditor(QWidget *parent) : QPlainTextEdit(parent), c(0){
     suchbox->setFlat(true);
     slt=new QGridLayout(suchbox);
     hidesearch = new QToolButton(suchbox);
-    hidesearch->setIcon(QIcon(":/icons/cancel.png"));
+    hidesearch->setIcon(QIcon(":/xle-icons/cancel.png"));
     hidesearch->setAutoRaise(true);
     prev = new QToolButton(suchbox);
-    prev->setIcon(QIcon(":/icons/moveleft.png"));
+    prev->setIcon(QIcon(":/xle-icons/moveleft.png"));
     prev->setText("Previous");
     prev->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
     prev->setAutoRaise(true);
     next = new QToolButton(suchbox);
-    next->setIcon(QIcon(":/icons/moveright.png"));
+    next->setIcon(QIcon(":/xle-icons/moveright.png"));
     next->setText("Next");
     next->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
     next->setAutoRaise(true);
@@ -99,19 +104,19 @@ CodeEditor::CodeEditor(QWidget *parent) : QPlainTextEdit(parent), c(0){
     replace->setMinimumSize(QSize(150, 0));
 
     replaceButton = new QToolButton(suchbox);
-    replaceButton->setIcon(QIcon(":/icons/moveright.png"));
+    replaceButton->setIcon(QIcon(":/xle-icons/moveright.png"));
     replaceButton->setText("Replace");
     replaceButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
     replaceButton->setAutoRaise(true);
 
     replacePButton = new QToolButton(suchbox);
-    replacePButton->setIcon(QIcon(":/icons/moveleft.png"));
+    replacePButton->setIcon(QIcon(":/xle-icons/moveleft.png"));
     replacePButton->setText("Replace");
     replacePButton->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
     replacePButton->setAutoRaise(true);
     replaceAButton= new QToolButton(suchbox);
     //ediVis=oupVis=false;
-    replaceAButton->setIcon(QIcon(":/icons/all.png"));
+    replaceAButton->setIcon(QIcon(":/xle-icons/all.png"));
 //
 
     replaceAButton->setText("Replace All!");
@@ -141,7 +146,7 @@ CodeEditor::CodeEditor(QWidget *parent) : QPlainTextEdit(parent), c(0){
 }
 
 CodeEditor::~CodeEditor(){
-  printf("CodeEditor will close%d\n",__LINE__);
+  //printf("CodeEditor will close%d\n",__LINE__);
   disconnect(this);
   //printf("ce%d\n",__LINE__);
   delete lineNumberArea;
@@ -149,7 +154,7 @@ CodeEditor::~CodeEditor(){
   delete afixHighlightArea;
   //printf("ce%d\n",__LINE__);
   delete highlighter;
-  printf("CodeEditor closed. %d %p\n",__LINE__,chgl);
+  //printf("CodeEditor closed. %d %p\n",__LINE__,chgl);
 
 }
 
@@ -203,6 +208,7 @@ void CodeEditor::resizeEvent(QResizeEvent *e){
 
 void CodeEditor::expandGreaterThan(){//!< some SHELXL re- or constrainst use > to specify a range of atoms this is a problem for sorting atoms
     QTextDocument *document = this->document();
+    printf("expandGreaterThan\n");
     for (int i=0; i<blocks.size(); i++){
         if (blocks.at(i).startsWith("REM",Qt::CaseInsensitive)) continue;
         if (blocks.at(i).contains('>')){
@@ -343,6 +349,25 @@ void CodeEditor::updateWght(){
   update();
 }
 
+void CodeEditor::insertList4(){
+    //we have a active LIST already in the file let's replace it
+    replace->setText("REM LIST ");
+    searchLE->setText("^LIST ");
+    replaceAll();
+    replace->setText("");
+    searchLE->setText("");
+  if (!toPlainText().contains(QRegExp("\nLIST",Qt::CaseInsensitive))){
+    QTextDocument *document = this->document();
+    QTextCursor cursor = textCursor();
+    cursor.movePosition(QTextCursor::Start,QTextCursor::MoveAnchor);
+    cursor = document->find(QRegExp("^UNIT",Qt::CaseInsensitive),cursor);
+    cursor.movePosition(QTextCursor::StartOfLine,QTextCursor::MoveAnchor);
+    cursor.movePosition(QTextCursor::Down,QTextCursor::MoveAnchor);
+    cursor.insertText("LIST 4\n");
+    emit saveMe(true,false);
+  }
+
+}
 
 void CodeEditor::insertList6(){
   if (!toPlainText().contains(QRegExp("\nLIST",Qt::CaseInsensitive))){
@@ -368,6 +393,7 @@ void CodeEditor::insertAnis(){
 }
 
 void CodeEditor::insertActa(){
+    insertList4();
   QTextDocument *document = this->document();
   QTextCursor cc,cursor = textCursor();
   cursor.movePosition(QTextCursor::Start,QTextCursor::MoveAnchor);
@@ -408,20 +434,30 @@ void CodeEditor::dispFromWave(){
     w=aw;
 
     int x=all.indexOf(QString("#S %1 %2").arg(sfac.at(i)+1,2,10,QChar('0')).arg(chgl->mol->pse(sfac.at(i))));
-    for (int j=x+1; j<4000+x; j++){
+    int y=all.indexOf(QString("#S %1 %2").arg(sfac.at(i)+2,2,10,QChar('0')).arg(chgl->mol->pse(sfac.at(i)+1)));
+    //printf("SFAC <<%d>> %s\n",x,QString("#S %1 %2").arg(sfac.at(i)+1,2,10,QChar('0')).arg(chgl->mol->pse(sfac.at(i))).toStdString().c_str());
+    //printf("SFAC <<%d>> %s\n",y,QString("#S %1 %2").arg(sfac.at(i)+2,2,10,QChar('0')).arg(chgl->mol->pse(sfac.at(i)+1)).toStdString().c_str());
+    for (int j=x+1; j<y; j++){
       an=nn;
-      nn=all.at(j).split(" ",QString::SkipEmptyParts);
+      nn=all.at(j).split(" ",skipEmptyParts);
       aw=w;
       w=nn.at(0).toDouble();
       if ((w!=aw)&&(chgl->mol->cell.wave>w)) {
         double f= (chgl->mol->cell.wave-aw)/(w-aw); 
-        //	printf("DISP $%s %f %f\n",chgl->mol->pse(sfac.at(i)).toStdString().c_str(),f*nn.at(1).toDouble()+(1-f)*an.at(1).toDouble(),f*nn.at(2).toDouble()+(1-f)*an.at(2).toDouble());
-        disp=QString("DISP $%1 %2 %3 %4!source kissel\n")//REM %5\nREM %6\n")
-          .arg(chgl->mol->pse(sfac.at(i)))
-          .arg(f*nn.at(1).toDouble()+(1-f)*an.at(1).toDouble(),8,'f',5)
-          .arg(f*nn.at(2).toDouble()+(1-f)*an.at(2).toDouble(),8,'f',5)
-          .arg(f*nn.at(3).toDouble()+(1-f)*an.at(3).toDouble(),8,'f',5)
-          ;
+            //printf("DISP $%s %f %f\n",chgl->mol->pse(sfac.at(i)).toStdString().c_str(),f*nn.at(1).toDouble()+(1-f)*an.at(1).toDouble(),f*nn.at(2).toDouble()+(1-f)*an.at(2).toDouble());
+            if (nn.size()>3){
+                disp=QString("DISP $%1 %2 %3 %4!source kissel\n")//REM %5\nREM %6\n")
+                  .arg(chgl->mol->pse(sfac.at(i)))
+                  .arg(f*nn.at(1).toDouble()+(1-f)*an.at(1).toDouble(),8,'f',5)
+                  .arg(f*nn.at(2).toDouble()+(1-f)*an.at(2).toDouble(),8,'f',5)
+                  .arg(f*nn.at(3).toDouble()+(1-f)*an.at(3).toDouble(),8,'f',5)
+                  ;}else{
+                disp=QString("DISP $%1 %2 %3!source kissel\n")//REM %5\nREM %6\n")
+                  .arg(chgl->mol->pse(sfac.at(i)))
+                  .arg(f*nn.at(1).toDouble()+(1-f)*an.at(1).toDouble(),8,'f',5)
+                  .arg(f*nn.at(2).toDouble()+(1-f)*an.at(2).toDouble(),8,'f',5)
+                  ;
+            }
         cursor.insertText(disp);
         j=5000+x;
       }
@@ -511,7 +547,7 @@ void CodeEditor::weedEmptySfacs(){
         pos++;
       }
       else {
-        pos+=cursor.selectedText().split(" ",QString::SkipEmptyParts).size()-1;
+        pos+=cursor.selectedText().split(" ",skipEmptyParts).size()-1;
         cursor.deleteChar();
         QString ac;
         for (int i =apos; i<newSfac.size() && i<pos+apos;i++) ac.append(QString("%1 ").arg(chgl->mol->pse(newSfac.at(i))));
@@ -647,7 +683,7 @@ void CodeEditor::findResi(QString index){
       centerCursor();
       c.clearSelection ();
       //QTextBlock b =c.block();
-      QStringList tt=index.split(QRegExp("\\s+"),QString::SkipEmptyParts);
+      QStringList tt=index.split(QRegExp("\\s+"),skipEmptyParts);
 
       int nr=0;
       if ((tt.size()>1)&&(tt.at(1).indexOf(QRegExp("^[0-9]+"))!=-1))
@@ -676,6 +712,7 @@ void CodeEditor::decreaseEdtiorFont(){
 }
 
 void CodeEditor::hideSearch(){
+  searchLE->clear();
   suchbox->hide();
 }
 
@@ -918,7 +955,7 @@ void CodeEditor::changeSortierWeise(QAction* action){
 
 QString CodeEditor::sortLabelList(CEnvironment &asymm, MyAtom &tatze){
     if (asymm.isEmpty()) return "HKLF";
-    QMap<long double,MyAtom> atomSortMap;
+    QMultiMap<long double,MyAtom> atomSortMap;
     long double lodo=0.0l;
     int amax = asymm.size();
 
@@ -940,7 +977,8 @@ QString CodeEditor::sortLabelList(CEnvironment &asymm, MyAtom &tatze){
                   n1+
                   ((110-asymm.at(i).an)/220.0l)+
                   (r1 / 50000.0l);//46656
-          atomSortMap.insertMulti(lodo,asymm.at(i));
+          //atomSortMap.insertMulti(lodo,asymm.at(i));
+          atomSortMap.insert(lodo,asymm.at(i));
           break;
         case 2:
           lodo=asymm.at(i).resiNr*99*amax+
@@ -949,7 +987,7 @@ QString CodeEditor::sortLabelList(CEnvironment &asymm, MyAtom &tatze){
                   ((110-asymm.at(i).an))+
                   (r1 / 50000.0l);//46656
 
-          atomSortMap.insertMulti(lodo,asymm.at(i));
+          atomSortMap.insert(lodo,asymm.at(i));
           //printf("##= %Lf %d %d %d %d %d\n",lodo,asymm.at(i).resiNr,asymm.at(i).part,n1,(110-asymm.at(i).an),r1);
           break;
         case 3:
@@ -958,7 +996,7 @@ QString CodeEditor::sortLabelList(CEnvironment &asymm, MyAtom &tatze){
                   n1/999.0l+
                   sfac.indexOf(asymm.at(i).an)*10+
                   (r1 / 50000.0l);//46656
-          atomSortMap.insertMulti(lodo,asymm.at(i));
+          atomSortMap.insert(lodo,asymm.at(i));
           break;
         case 4:
           lodo=
@@ -967,7 +1005,7 @@ QString CodeEditor::sortLabelList(CEnvironment &asymm, MyAtom &tatze){
           n1/50000.0l+
           ((110-asymm.at(i).an)/220)+
           (r1 );//46656
-          atomSortMap.insertMulti(lodo,asymm.at(i));
+          atomSortMap.insert(lodo,asymm.at(i));
           t2++;
           break;
         case 5:
@@ -978,7 +1016,7 @@ QString CodeEditor::sortLabelList(CEnvironment &asymm, MyAtom &tatze){
           n1/999.0l+
           ((110-asymm.at(i).an))+
           (r1 / 50000.0l);//46656
-          atomSortMap.insertMulti(lodo,asymm.at(i));
+          atomSortMap.insert(lodo,asymm.at(i));
           /*printf("%s %g\n", asymm.at(i).Label.toStdString().c_str(),asymm.at(i).molindex*9999*amax+
               asymm.at(i).resiNr*99*amax+
               asymm.at(i).part*amax+
@@ -986,6 +1024,13 @@ QString CodeEditor::sortLabelList(CEnvironment &asymm, MyAtom &tatze){
               ((110-asymm.at(i).an))+
               (r1 / 50000.0));*/
           break;
+        case 6:
+            lodo=  asymm.at(i).resiNr*99*amax+
+                    asymm.at(i).part*amax+
+                    chgl->mol->ueq(asymm.at(i).uf);
+
+        atomSortMap.insert(lodo,asymm.at(i));
+        break;
         default:
           atomSortMap.insert(i, asymm.at(i));
           break;
@@ -1039,6 +1084,11 @@ QString CodeEditor::sortLabelList(CEnvironment &asymm, MyAtom &tatze){
         ((110-tatze.an))+
         (r1 / 50000.0l);//46656
         break;
+    case 6:
+        lodo=  tatze.resiNr*99*amax+
+               tatze.part*amax+
+               chgl->mol->ueq(tatze.uf);
+        break;
     }
     }
     QList<long double> kys = atomSortMap.keys();
@@ -1070,6 +1120,96 @@ QString CodeEditor::sortLabelList(CEnvironment &asymm, MyAtom &tatze){
     atomSortMap.clear();
     return l;
 }
+void CodeEditor::sortAtoms(CEnvironment &as){
+    if (as.isEmpty()) return;
+    if (toPlainText().contains(QRegExp("[<>]"))){
+      expandGreaterThan();
+    }
+    QMap<long double,MyAtom> atomSortMap;
+
+    int amax = as.size();
+    int t1=0,t2=0;
+    for (int i=0; i < as.size(); i++){
+      if (as.at(i).an<0) continue;
+      t1++;
+      QString s1 = as.at(i).Label;
+      s1.remove(0,chgl->mol->pse(as.at(i).an).size());
+      int n1 = s1.section(QRegExp("\\D"),0,0).toInt();
+      int r1 = 0 ;
+      char cc[10];
+      strncpy(cc,s1.section(QRegExp("\\d+"),1,-1).toStdString().c_str(),4);
+      for (size_t k=0; k<strlen(cc);k++) {r1*=256;r1+=(size_t)cc[k];}
+      switch (sortierWeise){
+        case 1:
+          atomSortMap.insert(
+              as.at(i).resiNr*99*amax+
+              as.at(i).part*amax+
+              n1+
+              ((110-as.at(i).an)/220.0)+
+              (r1 / 50000.0)//46656
+              ,as.at(i));
+          break;
+        case 2:
+          atomSortMap.insert(
+              as.at(i).resiNr*99*amax+
+              as.at(i).part*amax+
+              n1/999.0+
+              ((110-as.at(i).an))+
+              (r1 / 50000.0)//46656
+              ,as.at(i));
+          break;
+        case 3:
+          atomSortMap.insert(
+              as.at(i).resiNr*99*amax+
+              as.at(i).part*amax+
+              n1/999.0+
+              sfac.indexOf(as.at(i).an)*10+
+              (r1 / 50000.0)//46656
+              ,as.at(i));
+          break;
+        case 4:
+          atomSortMap.insert(
+              as.at(i).resiNr*99*amax+
+              as.at(i).part*amax+
+              n1/50000.0+
+              ((110-as.at(i).an)/220)+
+              (r1 )//46656
+              ,as.at(i));
+          t2++;
+          break;
+        case 5:
+          atomSortMap.insert(
+              as.at(i).molindex*9999*amax+
+              as.at(i).resiNr*99*amax+
+              as.at(i).part*amax+
+              n1/999.0+
+              ((110-as.at(i).an))+
+              (r1 / 50000.0)//46656
+              ,as.at(i));
+          printf("%s %g\n", as.at(i).Label.toStdString().c_str(),as.at(i).molindex*9999*amax+
+              as.at(i).resiNr*99*amax+
+              as.at(i).part*amax+
+              n1/999.0+
+              ((110-as.at(i).an))+
+              (r1 / 50000.0));
+          break;
+
+      case 6:{
+          long double lodo=0.0l;
+          lodo=  as.at(i).resiNr*99*amax+
+                  as.at(i).part*amax+
+                  chgl->mol->ueq(as.at(i).uf);
+          atomSortMap.insert(lodo,as.at(i));
+      }
+      break;
+        default:
+          atomSortMap.insert(i
+              ,as.at(i));
+          break;
+      }
+    }
+    as=  atomSortMap.values();
+}
 
 void CodeEditor::sortAtoms(){
   if (chgl->mol->asymm.isEmpty()) return;
@@ -1110,7 +1250,7 @@ void CodeEditor::sortAtoms(){
     for (size_t k=0; k<strlen(cc);k++) {r1*=256;r1+=(size_t)cc[k];}
     switch (sortierWeise){
       case 1:
-        atomSortMap.insertMulti(
+        atomSortMap.insert(
             chgl->mol->asymm.at(i).resiNr*99*amax+
             chgl->mol->asymm.at(i).part*amax+
             n1+
@@ -1119,7 +1259,7 @@ void CodeEditor::sortAtoms(){
             ,chgl->mol->asymm.at(i));
         break;
       case 2:
-        atomSortMap.insertMulti(
+        atomSortMap.insert(
             chgl->mol->asymm.at(i).resiNr*99*amax+
             chgl->mol->asymm.at(i).part*amax+
             n1/999.0+
@@ -1128,7 +1268,7 @@ void CodeEditor::sortAtoms(){
             ,chgl->mol->asymm.at(i));
         break;
       case 3:
-        atomSortMap.insertMulti(
+        atomSortMap.insert(
             chgl->mol->asymm.at(i).resiNr*99*amax+
             chgl->mol->asymm.at(i).part*amax+
             n1/999.0+
@@ -1137,7 +1277,7 @@ void CodeEditor::sortAtoms(){
             ,chgl->mol->asymm.at(i));
         break;
       case 4:
-        atomSortMap.insertMulti(
+        atomSortMap.insert(
             chgl->mol->asymm.at(i).resiNr*99*amax+
             chgl->mol->asymm.at(i).part*amax+
             n1/50000.0+
@@ -1147,7 +1287,7 @@ void CodeEditor::sortAtoms(){
         t2++;
         break;
       case 5:
-        atomSortMap.insertMulti(
+        atomSortMap.insert(
             chgl->mol->asymm.at(i).molindex*9999*amax+
             chgl->mol->asymm.at(i).resiNr*99*amax+
             chgl->mol->asymm.at(i).part*amax+
@@ -1162,6 +1302,15 @@ void CodeEditor::sortAtoms(){
             ((110-chgl->mol->asymm.at(i).an))+
             (r1 / 50000.0));
         break;
+
+    case 6:{
+        long double lodo=0.0l;
+        lodo=  chgl->mol->asymm.at(i).resiNr*99*amax+
+                chgl->mol->asymm.at(i).part*amax+
+                chgl->mol->ueq(chgl->mol->asymm.at(i).uf);
+        atomSortMap.insert(lodo,chgl->mol->asymm.at(i));
+    }
+    break;
       default:
         atomSortMap.insert(i
             ,chgl->mol->asymm.at(i));
@@ -1197,14 +1346,15 @@ void CodeEditor::sortAtoms(){
     cursor.insertText("AFIX 0 \n");
   }
 
-  QProgressDialog progress("Sorting atoms in Editor", QString(), 0, asymm2.size(), this);
-  progress.setWindowModality(Qt::WindowModal);
+  /*QProgressDialog progress("Sorting atoms in Editor", QString(), 0, asymm2.size(), this);
+  progress.setWindowModality(Qt::WindowModal);*/
   int ares=0, apart=0;
   for (int i=0; i < asymm2.size(); i++){
-    progress.setValue(i);
+    //progress.setValue(i);
     QString  label = asymm2.at(i).orginalLine.left(80).trimmed();
     cursor.movePosition(QTextCursor::Start);
     cursor = document->find(label,cursor);
+    //printf("find=>>%s {%d}\n",label.toStdString().c_str(),cursor.blockNumber());
     if (cursor.isNull()){
       cursor = textCursor();
       cursor.movePosition(QTextCursor::Start);
@@ -1234,7 +1384,7 @@ void CodeEditor::sortAtoms(){
     cursor.deleteChar();
     cursor = textCursor();
     cursor.movePosition(QTextCursor::Start);
-    cursor = document->find("HKLF",cursor);
+    cursor = document->find(QRegExp("^HKLF",Qt::CaseInsensitive),cursor);
     cursor.clearSelection();
     cursor.movePosition(QTextCursor::StartOfLine);
     if ((asymm2.at(i).resiNr!=ares))
@@ -1244,6 +1394,7 @@ void CodeEditor::sortAtoms(){
     if ((asymm2.at(i).part!=apart))
       cursor.insertText(QString("PART %1\n")
           .arg(asymm2.at(i).part));
+    //printf("=>%d\n",cursor.blockNumber());
     cursor.insertText(neues);
     cursor.insertText("\n");
     ares = asymm2.at(i).resiNr;
@@ -1269,7 +1420,7 @@ void CodeEditor::sortAtoms(){
   wholeLine->setChecked(false);
   setTextCursor(cursor);
 
-  progress.setValue(asymm2.size());
+  //progress.setValue(asymm2.size());
 }
 
 void CodeEditor::sortSelectedRegion(){
@@ -1317,14 +1468,14 @@ void CodeEditor::sortSelectedRegion(){
     for (size_t k=0; k<strlen(cc);k++) {r1*=256;r1+=(size_t)cc[k];}
     switch (sortierWeise){
       case 1:
-        atomSortMap.insertMulti(
+        atomSortMap.insert(
             toms.at(i).resiNr*99*amax+
             toms.at(i).part*amax+
             n1+
             ((110-toms.at(i).an)/220.0)+
             (r1 / 50000.0)//46656
             ,toms.at(i));
-        atomSortMapi.insertMulti(
+        atomSortMapi.insert(
             toms.at(i).resiNr*99*amax+
             toms.at(i).part*amax+
             n1+
@@ -1333,14 +1484,14 @@ void CodeEditor::sortSelectedRegion(){
             ,i);
         break;
       case 2:
-        atomSortMap.insertMulti(
+        atomSortMap.insert(
             toms.at(i).resiNr*99*amax+
             toms.at(i).part*amax+
             n1/999.0+
             ((110-toms.at(i).an))+
             (r1 / 50000.0)//46656
             ,toms.at(i));
-        atomSortMapi.insertMulti(
+        atomSortMapi.insert(
             toms.at(i).resiNr*99*amax+
             toms.at(i).part*amax+
             n1/999.0+
@@ -1349,14 +1500,14 @@ void CodeEditor::sortSelectedRegion(){
             ,i);
         break;
       case 3:
-        atomSortMap.insertMulti(
+        atomSortMap.insert(
             toms.at(i).resiNr*99*amax+
             toms.at(i).part*amax+
             n1/999.0+
             sfac.indexOf(toms.at(i).an)*10+
             (r1 / 50000.0)//46656
             ,toms.at(i));
-        atomSortMapi.insertMulti(
+        atomSortMapi.insert(
             toms.at(i).resiNr*99*amax+
             toms.at(i).part*amax+
             n1/999.0+
@@ -1365,14 +1516,14 @@ void CodeEditor::sortSelectedRegion(){
             ,i);
         break;
       case 4:
-        atomSortMap.insertMulti(
+        atomSortMap.insert(
             toms.at(i).resiNr*99*amax+
             toms.at(i).part*amax+
             n1/50000.0+
             ((110-toms.at(i).an)/220)+
             (r1 )//46656
             ,toms.at(i));
-        atomSortMapi.insertMulti(
+        atomSortMapi.insert(
             toms.at(i).resiNr*99*amax+
             toms.at(i).part*amax+
             n1/50000.0+
@@ -1382,7 +1533,7 @@ void CodeEditor::sortSelectedRegion(){
         t2++;
         break;
       case 5:
-        atomSortMap.insertMulti(
+        atomSortMap.insert(
             toms.at(i).molindex*9999*amax+
             toms.at(i).resiNr*99*amax+
             toms.at(i).part*amax+
@@ -1390,7 +1541,7 @@ void CodeEditor::sortSelectedRegion(){
             ((110-toms.at(i).an))+
             (r1 / 50000.0)//46656
             ,toms.at(i));
-        atomSortMapi.insertMulti(
+        atomSortMapi.insert(
             toms.at(i).molindex*9999*amax+
             toms.at(i).resiNr*99*amax+
             toms.at(i).part*amax+
@@ -1551,7 +1702,7 @@ void CodeEditor::insertCHIV(double vol, double esd1, QList<MyAtom> selected, QSt
 }
 
 void CodeEditor::omitsome(const QString &s){
-  //qDebug()<<"omi->t"<<s.size();
+  //  qDebug()<<"omi->t"<<s.size()<<s;
   QList<Omit> schonWeg;        
   Omit o;
   QTextDocument *document = this->document();
@@ -1561,7 +1712,7 @@ void CodeEditor::omitsome(const QString &s){
   while (!cursor.isNull()){
     cursor = document->find(QRegExp("OMIT\\s+\\d+\\s+\\d+\\s+\\d+"),cursor);
     if (!cursor.isNull()){
-      sli=cursor.selectedText().split(" ",QString::SkipEmptyParts);
+      sli=cursor.selectedText().split(" ",skipEmptyParts);
       o.h=sli.at(1).toInt();
       o.k=sli.at(2).toInt();
       o.l=sli.at(3).toInt();
@@ -1586,7 +1737,62 @@ void CodeEditor::omitsome(const QString &s){
 void CodeEditor::lineNumberAreaPaintEvent(QPaintEvent *event){
   QPainter painter(lineNumberArea);
   int current = textCursor().blockNumber();
-  painter.fillRect(event->rect(), QColor("#eeeeee"));
+  if (!dark){
+      painter.fillRect(event->rect(), QColor("#eeeeee"));
+        QTextBlock block = firstVisibleBlock();
+       // printf("edidor Font: %s italic%d bold %d point %d pixel %d height %d\n",fontInfo().family().toStdString().c_str(),fontInfo().italic (),fontInfo().bold (),fontInfo().pointSize (),fontInfo().pixelSize (),fontMetrics().height());
+      //   printf("lineNumberAreaPaintEvent\n");
+        int blockNumber = block.blockNumber();
+        int top = (int) blockBoundingGeometry(block).translated(contentOffset()).top();
+        int bottom = top + (int) blockBoundingRect(block).height();
+        // printf ("line %d %d\n",top,bottom);
+        int minbl=8888888,maxbl=0;
+        while (block.isValid() && top <= event->rect().bottom()) {
+          if (block.isVisible() && bottom >= event->rect().top()) {
+            QString number = QString::number(blockNumber + 1);
+            bool iscurrent=(blockNumber==current);
+            if (blockNumber%2) painter.fillRect(0, top,
+                                            lineNumberArea->width(),
+                                            fontMetrics().height(),QColor("#dddddd"));
+            if (iscurrent) painter.fillRect(0, top,
+                                            lineNumberArea->width(),
+                                            fontMetrics().height(),QColor("#242424"));
+            // /*
+            QFont f=painter.font();
+            if (errorInLine.contains(blockNumber)) {
+          painter.fillRect(0, top,
+                  lineNumberArea->width(),
+                  fontMetrics().height(),QColor("#aa0000"));
+          iscurrent=true;
+            }
+            if (comment.at(blockNumber)) {
+          painter.fillRect(5, top+2,
+                  3,//lineNumberArea->width()
+                  fontMetrics().height()-4,(iscurrent)?QColor("#99aaff"):QColor("#0000aa"));
+            }
+
+
+            //printf("edidor Font: %s %d %d %d\n",f.family().toStdString().c_str(),f.pointSize(),fontMetrics().height(),fontMetrics().lineSpacing ());
+            f.setWeight((iscurrent)?QFont::Black:QFont::Light);
+            painter.setFont(f);
+            // */
+            painter.setPen((iscurrent)?Qt::white:Qt::darkGray);
+            painter.drawText(0, top,
+                    lineNumberArea->width(),
+                            fontMetrics().lineSpacing () ,
+                            Qt::AlignRight, number);
+            minbl=qMin(minbl,blockNumber + 1);
+            maxbl=qMax(maxbl,blockNumber + 1);
+          }
+          if (ListFile)
+          midCursorpos=(minbl+maxbl)/2;
+          block = block.next();
+          top = bottom;
+          bottom = top + (int) blockBoundingRect(block).height();
+          ++blockNumber;
+        }
+  }else{
+  painter.fillRect(event->rect(), QColor("#242424"));//"#eeeeee"));
   QTextBlock block = firstVisibleBlock();
  // printf("edidor Font: %s italic%d bold %d point %d pixel %d height %d\n",fontInfo().family().toStdString().c_str(),fontInfo().italic (),fontInfo().bold (),fontInfo().pointSize (),fontInfo().pixelSize (),fontMetrics().height());
 //   printf("lineNumberAreaPaintEvent\n");
@@ -1601,10 +1807,10 @@ void CodeEditor::lineNumberAreaPaintEvent(QPaintEvent *event){
       bool iscurrent=(blockNumber==current);
       if (blockNumber%2) painter.fillRect(0, top,
                                       lineNumberArea->width(),
-                                      fontMetrics().height(),QColor("#dddddd"));
+                                      fontMetrics().height(),QColor("424242"));//"#dddddd"));
       if (iscurrent) painter.fillRect(0, top,
                                       lineNumberArea->width(),
-                                      fontMetrics().height(),QColor("#242424"));
+                                      fontMetrics().height(),QColor("#eeeeee"));
       // /*
       QFont f=painter.font();
       if (errorInLine.contains(blockNumber)) {
@@ -1616,7 +1822,7 @@ void CodeEditor::lineNumberAreaPaintEvent(QPaintEvent *event){
       if (comment.at(blockNumber)) {
     painter.fillRect(5, top+2,
 			3,//lineNumberArea->width()
-            fontMetrics().height()-4,(iscurrent)?QColor("#99aaff"):QColor("#0000aa"));
+            fontMetrics().height()-4,(!iscurrent)?QColor("#99aaff"):QColor("#0000aa"));
       }
       
       
@@ -1624,7 +1830,7 @@ void CodeEditor::lineNumberAreaPaintEvent(QPaintEvent *event){
       f.setWeight((iscurrent)?QFont::Black:QFont::Light);
       painter.setFont(f);
       // */
-      painter.setPen((iscurrent)?Qt::white:Qt::darkGray);
+      painter.setPen((!iscurrent)?Qt::lightGray:Qt::black);
       painter.drawText(0, top,
 		      lineNumberArea->width(), 
                       fontMetrics().lineSpacing () ,
@@ -1639,6 +1845,7 @@ void CodeEditor::lineNumberAreaPaintEvent(QPaintEvent *event){
     bottom = top + (int) blockBoundingRect(block).height();
     ++blockNumber;
   }
+  }
 
 
   //updateAfix();
@@ -1758,7 +1965,7 @@ if (!cu.isNull()) setTextCursor(cu);
 void CodeEditor::afixHighlightAreaPaintEvent(QPaintEvent *event){
 //   printf("\nafixHighlightAreaPaintEvent\n");
   QPainter apainter(afixHighlightArea);
-  apainter.fillRect(afixHighlightArea->rect(), QColor("#fafaf0"));
+  apainter.fillRect(afixHighlightArea->rect(), (dark)?QColor("#242424"):QColor("#fafafa"));
   QTextBlock block = firstVisibleBlock();
   QColor color;
   QColor pcolor;
@@ -1769,35 +1976,16 @@ void CodeEditor::afixHighlightAreaPaintEvent(QPaintEvent *event){
   int bottom = top + (int) blockBoundingRect(block).height();
   //printf ("afix %d %d %d %d \n",top,bottom,block.isVisible(),event->rect().top());
   while (block.isValid() && top <= event->rect().bottom()) {
-  switch (parenthesis.at(blockNumber)){ 
-  case 0: color=QColor("#fafaf0");
-      //          Qt::white;
-          break;
-  case 1: color=Qt::darkGreen;break;
-  default: 
-          color=QColor("blueviolet");
-          break;
-  }
-  switch (parenthesis2.at(blockNumber)){ 
-  case 0: pcolor=QColor("#fafaf0");
-              //Qt::white;
+      switch (parenthesis.at(blockNumber)){
+      case 0: color=(dark)?QColor("#242424"):QColor("#fafafa");
+          //          Qt::white;
               break;
-  case 1: pcolor=QColor("lightskyblue");break;
-  case 2: pcolor=QColor("darkgoldenrod");break;
-  case 3: pcolor=Qt::green;break;
-  case 4: pcolor=Qt::yellow;break;
-  case 5: pcolor=QColor("orange");break;
-  case 6: pcolor=Qt::black;break;
-  case 7: pcolor=QColor("lightsalmon");break;
-  case 8: pcolor=QColor("lightseagreen");break;
-  case -1: pcolor=QColor("aquamarine");break;
-  case -2: pcolor=QColor("olive");break;
-  case -3: pcolor=QColor("bisque");break;
-  default: if (parenthesis2.at(blockNumber)>0)
-          pcolor=QColor::colorNames().at(qMin(parenthesis2.at(blockNumber),QColor::colorNames().size()-1));
-      else pcolor=Qt::magenta;
-  }
-
+      case 1: color=Qt::darkGreen;break;
+      default:
+              color=QColor("blueviolet");
+              break;
+      }
+      pcolor=PartColor::color(parenthesis2.at(blockNumber),dark);
     if (block.isVisible() && bottom >= event->rect().top()) {
     //  printf("%d %d %d %d %d %d\n",0,top, 4,fontMetrics().height(),parenthesis.at(blockNumber),blockNumber);
       apainter.fillRect(5,top, 4,fontMetrics().lineSpacing (),color);
@@ -1811,13 +1999,32 @@ void CodeEditor::afixHighlightAreaPaintEvent(QPaintEvent *event){
   event->accept();
 }
 
+void CodeEditor::hoverLineNumber(QMouseEvent *event){
+    if (!isVisible()) {event->ignore(); return;}
+    //fontMetrics().lineSpacing ()
+    QTextBlock block=firstVisibleBlock();
+    int top = (int) blockBoundingGeometry(block).translated(contentOffset()).top();
+    int bn=firstVisibleBlock().blockNumber();
+    int idx=(int)  (event->y()-top)/ ((int) blockBoundingRect(block).height()) + bn;
+    if (idx>=parenthesis.size()) {event->accept();return;}
+    QString msg=QString("Line:%6<br>%1 PART=%2 <br>%3 Color: %4 <font color=%5>#######</font> %5")
+            .arg((parenthesis.at(idx))?"AFIXed<br>":"")
+            .arg(parenthesis2.at(idx))
+            .arg((comment.at(idx))?"This line is a comment.<br>":"")
+            .arg(PartColor::name(parenthesis2.at(idx),dark))
+            .arg(PartColor::color(parenthesis2.at(idx),dark).name())
+            .arg(idx+1)            
+            ;
+    QToolTip::showText(event->globalPos(),msg);
+    event->accept();
+}
 bool CodeEditor::viewportEvent(QEvent *event){
 //  printf("lala %d\n",event->type());
 if (!isVisible()) {event->ignore(); return false;}
 if (event->type() == QEvent::ToolTip) {
-  QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);
+  QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);  
   QTextCursor cursor = cursorForPosition( helpEvent->pos());
-  if(cursor.block().text().isEmpty()) return true;
+  if(cursor.block().text().isEmpty()) return true;  
   QStringList block=shxToolTips.filter(cursor.block().text().left(4),Qt::CaseInsensitive);
   if (block.size())
     QToolTip::showText(helpEvent->globalPos(),block.first());
@@ -2119,4 +2326,3 @@ void CodeEditor::keyPressEvent(QKeyEvent *e){
     c->complete(cr); // popup it up!
 }
 
-
