@@ -1,7 +1,7 @@
 /*
  ----------------------------------------------------------------------------
  "THE BEER-WARE LICENSE" (Revision 42):
- <daniel.kratzert@ac.uni-freiburg.de> wrote this file. As long as you retain
+ <dkratzert@gmx.de> wrote this file. As long as you retain
  this notice you can do whatever you want with this stuff. If we meet some day,
  and you think this stuff is worth it, you can buy me a beer in return.
  Daniel Kratzert
@@ -11,6 +11,7 @@
 #include <QtGui>
 #include "dsreditwindow.h"
 #include "dsrglwindow.h"
+#include "deprecation.h"
 
 /*
    TODO:
@@ -564,7 +565,7 @@ void DSREditWindow::setRestraintsFromDB(DSRMol *header) {
   myRestraints.clear();
   for (int i=0; i<restr.size(); i++) {
     restrEdit->append(restr.at(i));
-    myRestraints.append(restr.at(i).split(" ", QString::SkipEmptyParts));
+    myRestraints.append(restr.at(i).split(" ", skipEmptyParts));
   }
   cursor.movePosition(QTextCursor::Start, QTextCursor::MoveAnchor);
   restrEdit->setTextCursor(cursor);
@@ -675,7 +676,7 @@ void DSREditWindow::renameAtoms(){
               this, SLOT(renameAtoms()));
       return;
     }
-    line_split = line.split(" ", QString::SkipEmptyParts);
+    line_split = line.split(" ", skipEmptyParts);
     if (line_split.length() > 0){
       line_split[0] = line_split.at(0).left(4);
       new_atnames.append(line_split.at(0).toUpper()); // collect new atom names after after a character was changed
@@ -711,7 +712,7 @@ void DSREditWindow::renameAtoms(){
     // use the new names + the previous atoms
     line = new_atnames.at(onum).leftJustified(4, ' ').left(4)+line.remove(0, 4);
     atomsEdit->append(line);
-    myAtoms.append(line.split(' ', QString::SkipEmptyParts));
+    myAtoms.append(line.split(' ', skipEmptyParts));
     onum++;
   }
   renameRestraints(new_atnames, cursopos);
@@ -737,7 +738,7 @@ void DSREditWindow::setAtoms(){
   QStringList atnames;
   int num = 0;
   foreach (QString line, atomsEdit->toPlainText().split(QRegExp("\n|\r\n|\r"))) {
-    line_split = line.split(" ", QString::SkipEmptyParts);
+    line_split = line.split(" ", skipEmptyParts);
     line_split = checkAtomLine(line_split, num+1);
     myAtoms.append(line_split);
     if (line_split.length() > 0){
@@ -912,7 +913,7 @@ void DSREditWindow::setRestraints() {
   QStringList line_split;
   int num = 0;
   foreach (QString line, restrEdit->toPlainText().split(QRegExp("\n|\r\n|\r"))) {
-    line_split = line.split(" ", QString::SkipEmptyParts);
+    line_split = line.split(" ", skipEmptyParts);
     checkRestraintLine(line_split, num+1);
     myRestraints.append(line_split);
     num++;
