@@ -1,7 +1,7 @@
 /*
  ----------------------------------------------------------------------------
  "THE BEER-WARE LICENSE" (Revision 42):
- <daniel.kratzert@ac.uni-freiburg.de> wrote this file. As long as you retain
+ <dkratzert@gmx.de> wrote this file. As long as you retain
  this notice you can do whatever you want with this stuff. If we meet some day,
  and you think this stuff is worth it, you can buy me a beer in return.
  Daniel Kratzert
@@ -115,6 +115,10 @@ void DSRGlWindow::draw(){
   GLdouble proj[16];
   GLint viewport[4];
   glGetIntegerv(GL_VIEWPORT, viewport);
+#if defined Q_OS_MAC && (QT_VERSION >= 0x050000)
+  viewport[2]/=2;
+  viewport[3]/=2;
+#endif
   //      printf("%d %d %d %d\n",viewport[0],viewport[1],viewport[2],viewport[3]);
   glGetDoublev( GL_PROJECTION_MATRIX, (double*)proj );
   glGetDoublev( GL_MODELVIEW_MATRIX, (double*)model );
@@ -191,9 +195,9 @@ void DSRGlWindow::initializeGL(){
   //glEnable(GL_POLYGON_SMOOTH);   
   myFont = QFont("Arial", 12, -1, false);  // the initial label font size
   const GLfloat  position[] = {100.0f, 100.0f,100.0f,0.0f};
-  const GLfloat  diffuse[]  = { 1.0, 1.0, 1.0, 1.0 };
-  const GLfloat  specular[] = { 1.0, 0.9, 0.9, 1.0 };
-  const GLfloat  ambient[]  = { 0.4, 0.4, 0.4, 1.0 };
+  const GLfloat  diffuse[]  = { 1.0f, 1.0f, 1.0f, 1.0f };
+  const GLfloat  specular[] = { 1.0f, 0.9f, 0.9f, 1.0f };
+  const GLfloat  ambient[]  = { 0.4f, 0.4f, 0.4f, 1.0f };
   glLightModeli(  GL_LIGHT_MODEL_LOCAL_VIEWER, 1 );
   glLightfv( GL_LIGHT0, GL_POSITION, position );
   glLightfv( GL_LIGHT0, GL_AMBIENT,  ambient );
@@ -218,7 +222,7 @@ void DSRGlWindow::initializeGL(){
   glMaterialf(  GL_FRONT_AND_BACK, GL_SHININESS,           OBJ_SHIN );
   glShadeModel( GL_SMOOTH );
   glEnable(GL_NORMALIZE);
-  glClearColor(0.6,0.6,0.6,1.0);
+  glClearColor(0.6f,0.6f,0.6f,1.0f);
   glEnable(GL_DEPTH_TEST );
   glDepthFunc(GL_LEQUAL);
   gluLookAt_(0.0, 200, 50 ,   0.0, 0.0, 0.0,   0.0, -100, 400 );
@@ -226,7 +230,11 @@ void DSRGlWindow::initializeGL(){
 }
 
 void DSRGlWindow::resizeGL(int width, int height){
-  glViewport(0, 0, width, height);
+#if defined Q_OS_MAC && (QT_VERSION >= 0x050000)
+  glViewport(0, 0, width*2,height*2);        
+#else  
+  glViewport(0, 0, width, height);        
+#endif
   glGetIntegerv(GL_VIEWPORT, vp);
   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();
@@ -244,9 +252,13 @@ QSize DSRGlWindow::sizeHint() const
 }
 
 void DSRGlWindow::paintGL(){
-  glClearColor(0.6,0.6,0.6,1.0); // The background color
+  glClearColor(0.6f,0.6f,0.6f,1.0f); // The background color
   glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
+#if defined Q_OS_MAC && (QT_VERSION >= 0x050000)
+  glViewport(0, 0, QGLWidget::width()*2, QGLWidget::height()*2);        
+#else  
   glViewport(0, 0, QGLWidget::width(), QGLWidget::height());        
+#endif
   glGetIntegerv(GL_VIEWPORT, vp);
   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();
@@ -415,7 +427,51 @@ void DSRGlWindow::makeInfo(){
     tryfit();
 }
 
-void glRotateL(double ang, double x, double y, double z);
+//void glRotateL(double ang, double x, double y, double z);
+inline void DSRGlWindow::__RotateCS( double c, double s, double& X, double& Y ) {
+  double T = X;
+  X = c*X - s*Y;
+  Y = s*T + c*Y;
+}
+
+void DSRGlWindow::glTranslateL( const double dx, const double dy, const double dz ) {
+  double mat[4][4];
+
+  glGetDoublev( GL_MODELVIEW_MATRIX, (double*)mat );
+  mat[3][0] += dx;  mat[3][1] += dy;  mat[3][2] += dz;
+  glLoadMatrixd((double*)mat);
+}
+void DSRGlWindow::glRotateL( const double dang, const double x, const double y, const double z ) {
+  double mat[4][4];
+#ifndef M_PI
+#define	M_PI		3.14159265358979323846	/* pi */
+#endif
+
+  double s = z;
+  s = sin(dang*M_PI/180);
+  const double c = cos(dang*M_PI/180);
+  glGetDoublev( GL_MODELVIEW_MATRIX, (double*)mat );
+  //  glGetDoublev( GL_PROJECTION_MATRIX, (double*)mat );
+  if( x!=0.0 ){
+    __RotateCS( c, s, mat[0][1], mat[0][2] );
+    __RotateCS( c, s, mat[1][1], mat[1][2] );
+    __RotateCS( c, s, mat[2][1], mat[2][2] );
+    //    printf("x\n");
+  }else if( y!=0.0 ){
+    __RotateCS( c, s, mat[0][2], mat[0][0] );
+    __RotateCS( c, s, mat[1][2], mat[1][0] );
+    __RotateCS( c, s, mat[2][2], mat[2][0] );
+    //    printf("y\n");
+  }else{
+    __RotateCS( c, s, mat[0][0], mat[0][1] );
+    __RotateCS( c, s, mat[1][0], mat[1][1] );
+    __RotateCS( c, s, mat[2][0], mat[2][1] );
+    //    printf("z\n");
+  }
+  glLoadMatrixd((double*)mat);
+}
+
+
 
 void DSRGlWindow::mouseMoveEvent(QMouseEvent *event){
   //! Either rotates (left mouse button) the molecule
@@ -426,7 +482,7 @@ void DSRGlWindow::mouseMoveEvent(QMouseEvent *event){
   GLfloat dy = GLfloat( event->y() - mouy) / height();
   if((event->buttons() & Qt::RightButton)){
     glScaled(1.0-dy,1.0-dy,1.0-dy);
-  }else{
+  }else if((event->buttons() && Qt::LeftButton)){
     glRotateL(dy*360.0,1.0,0.0,0.0);
     glRotateL(dx*360.0,0.0,1.0,0.0);
   }
