@@ -35,7 +35,10 @@ protected:
   void paintGL();
   void mouseMoveEvent(QMouseEvent *event); 
   void wheelEvent(QWheelEvent *event);
-private:
+private:  
+  inline void __RotateCS( double c, double s, double& X, double& Y ) ;
+  void glTranslateL( const double dx, const double dy, const double dz );
+  void glRotateL( const double dang, const double x, const double y, const double z );
   QFont myFont; //!< a font for the atom labels
   Molecule mole;
   QColor dsrLabelColor;
