@@ -1,7 +1,7 @@
 /*
  ----------------------------------------------------------------------------
  "THE BEER-WARE LICENSE" (Revision 42):
- <daniel.kratzert@ac.uni-freiburg.de> wrote this file. As long as you retain
+ <dkratzert@gmx.de> wrote this file. As long as you retain
  this notice you can do whatever you want with this stuff. If we meet some day,
  and you think this stuff is worth it, you can buy me a beer in return.
  Daniel Kratzert
@@ -16,6 +16,7 @@
 #include "window.h"
 #include "dsrglwindow.h"
 #include "dsreditwindow.h"
+#include "deprecation.h"
 #include "itsme.h"
 
 #if defined(Q_OS_WIN) || defined(Q_WS_WIN32)
@@ -27,7 +28,7 @@
 /*
 Explanations
 
-- This GUI is for DSR https://www.xs3.uni-freiburg.de/research/dsr
+- This GUI is for DSR https://dkratzert.de/dsr.html
 - DSR stores the information for pre-defined molecular fragments and their
   restraints in a text database in $DSR_DB_DIR.
 - This GUI uses that information to provide a convenient interface for DSR.
@@ -120,7 +121,7 @@ DSRGui::DSRGui(Molecule *mole, QString shelxlPath, Window *parent): QWidget(pare
   fvarLabel->setStyleSheet("QPushButton {border-style: outset; border-width: 0px;}");  // remove border to appear like a label
   occLabel = new QLabel(tr("Occupancy"));
   classLabel = new QLabel(tr("Residue Class"));
-  usermanualLabel = new QLabel(tr("<a href=\"https://www.xs3-data.uni-freiburg.de/data/DSR-manual.pdf\"> DSR User Manual </a>"));
+  usermanualLabel = new QLabel(tr("<a href=\"https://github.com/dkratzert/DSR/raw/master/manuals/DSR-manual.pdf\"> DSR User Manual </a>"));
   usermanualLabel->setOpenExternalLinks(true);
   resnumbertext = new QString(tr("A residue number will be\nchosen automatically."));
   resiTextLabel = new QLabel();
@@ -264,7 +265,7 @@ DSRGui::DSRGui(Molecule *mole, QString shelxlPath, Window *parent): QWidget(pare
     connect(sm, SIGNAL(currentRowChanged(QModelIndex,QModelIndex)),
         this, SLOT(setFragName(QModelIndex)), Qt::UniqueConnection);
   }
-  this->move(m_shelxle->width()-this->width()-30, 30);
+  this->move(QApplication::desktop()->width()-this->width()-30, 30);
   this->resize(this->width()-2, this->height()-2);  // a trick to redraw the gl windows
   if (!(dsrVersion.toLatin1() == "0")) {
     outtext->append(QString("\nFound DSR version %1.").arg(dsrVersion));
@@ -279,6 +280,28 @@ DSRGui::~DSRGui() {
   delete mygl;
 }
 
+void DSRGui::aboutDSR() {
+  QMessageBox::about(this, QString(tr("About DSR Plugin")),//only one about dlg in macOS
+      QString(
+        tr("<p><b>DSR plugin for ShelXle</b></p>"
+          "This plugin is a graphical interface for DSR.<br>"
+          "The GUI part and the interaction with DSR was developed by <b>Daniel Kratzert</b>, "
+          "while the 3D OpenGL part was developed by <b>Christian H&uuml;bschle</b>.<br>"
+          "DSR is a refinement tool with a database of molecular fragments and corresponding restraints.<br>"
+          "Place these fragments in a molecular structure to model disorder or just quickly rename "
+          "groups of atoms.<br><br>"
+          "Please cite DSR as:<br>"
+          "<a href=https://dkratzert.de/files/dsr/documents/dsr_2_reprint.pdf> D. Kratzert, I. Krossing, <i>J. Appl. Cryst.</i><b> 2018</b>, <i>51</i>, 928-934.<br></a>"
+          "<a href=https://doi.org/10.1107/S1600576718004508> doi:10.1107/S1600576718004508 </a><br><br>"
+          "If you have additional fragments for the DSR database or a bug to report, please send them to "
+          "<a href=\"dkratzert@gmx.de\"> dkratzert@gmx.de </a> <br>"
+          "Please find the most recent version of DSR at <br>"
+          "<a href=\"https://dkratzert.de/dsr.html\"> https://dkratzert.de/dsr.html </a><br><br>"
+          "All DSR related software is developed at GitHub:<br>"
+          "<a href=\"https://github.com/dkratzert/DSR\"> https://github.com/dkratzert/DSR </a><br><br>"
+          "Please refer to the <a href=\"http://www.xs3-data.uni-freiburg.de/data/DSR-manual.pdf\"> manual </a> if you have any questions."
+          )));
+}
 
 void DSRGui::connect_signals_and_slots() {
   //! Handles most of the signal slot connections
@@ -426,8 +449,8 @@ void DSRGui::isDSRUpToDate(QNetworkReply* reply) {
                    "This is revision: <b>%1</b><br> "
                    "The latest version is: <b>%2</b> <br><br>"
                    "New versions can be downloaded here: <br>"
-                   "<a href=\"https://www.xs3.uni-freiburg.de/research/dsr\">"
-                   "https://www.xs3.uni-freiburg.de/research/dsr</a><br><br>"
+                   "<a href=\"https://dkratzert.de/dsr.html\">"
+                   "https://dkratzert.de/dsr.html</a><br><br>"
                    "Please contact the author Daniel Kratzert"
                    " <a href=\"mailto:dkratzert@gmx.de\">dkratzert@gmx.de</a> "
                    "if you find any bugs.<br> Thank you!")
@@ -525,8 +548,8 @@ void DSRGui::checkForDSRexecutable(QSplashScreen *splash) {
     outtext->append(QString(tr("Unable to find DSR executable."
                 "\nIs DSR_DIR environment variable set correctly?")));
     outtext->append(QString(tr("Please find the most recent version of DSR at "
-                               "<a href=\"https://www.xs3.uni-freiburg.de/research/dsr\">"
-                               "https://www.xs3.uni-freiburg.de/research/dsr</a>")));
+                               "<a href=\"https://dkratzert.de/dsr.html\">"
+                               "https://dkratzert.de/dsr.html</a>")));
     splash->finish(this);
   }
 }
@@ -539,8 +562,8 @@ void DSRGui::setToolTips() {
                              "PART 0 \nin 1.3A distance around the fitted fragment atoms."));
   occEdit->setToolTip(tr("The occupancy of the fragment\n"));
   fvarspinner->setToolTip(tr("The Free Variable for the fragment.\n"
-                             "Free Variable and Occupation will be combined occording to the SHELXL syntax.\n"
-                             "For example, 21.0 means second free variable with occupation of 1."));
+                             "Free Variable and Occupancy will be combined occording to the SHELXL syntax.\n"
+                             "For example, 21.0 means second free variable with occupancy of 1."));
   invertFragBox->setToolTip(tr("Invert the fragment coordinates during fit."));
   runExtBox->setToolTip(tr("Write restraints to external file."));
   dfixBox->setToolTip(tr("Calculate DFIX/DANG/FLAT restraints "
@@ -604,7 +627,7 @@ bool DSRGui::open_last_fileversion() {
     QString savehist_content = savehist.readAll();  //Entry|@|2011-03-08T13:32:19|@|b11.res|@|
     savehist.close();
     QRegExp re = QRegExp("Entry\\|@\\|\\w+-\\w+-\\w+:\\w+:\\w+\\|@\\|[^@]+@\\|");
-    QStringList entries = savehist_content.split(re, QString::SkipEmptyParts);
+    QStringList entries = savehist_content.split(re, skipEmptyParts);
     QFile f(m_shelxle->dirName);
     bool success = f.open(QIODevice::WriteOnly|QIODevice::Text);
     if (success){
@@ -1063,7 +1086,7 @@ void DSRGui::setFvarOcc(void) {
   double occ = 0;
   double focc = 0;
   fvar = fvarspinner->value();
-  occ = (occEdit->text().toDouble());
+  occ = (occEdit->text().replace(',', '.').toDouble());
   if (fvar < 0) {
     focc = -(abs(fvar) * 10 + occ);
   } else {
@@ -1375,7 +1398,7 @@ bool DSRGui::runDSR(QString option, bool showresults, QString workdir) {
     // Need to do this, because en empty path would cause dsr.start() to fail.
     dsr.setWorkingDirectory(resfip.absolutePath());
   }
-  dsr.start(dsrpath, option.split(" ", QString::SkipEmptyParts));
+  dsr.start(dsrpath, option.split(" ", skipEmptyParts));
   if (!dsr.waitForFinished()) {
     outtext->append("Unable to start DSR.");
     outtext->append(dsrpath + " " + option);
@@ -1499,7 +1522,7 @@ bool DSRGui::listDSRdbFragments(QString fav="None") {
   if (!versionOk) {
     outtext->clear();
     outtext->append(QString(tr("Detected an old version of DSR.")));
-    outtext->append(QString(tr("Please get the most recent version from https://www.xs3.uni-freiburg.de/research/dsr")));
+    outtext->append(QString(tr("Please get the most recent version from https://dkratzert.de/dsr.html")));
     return false;
   }
   displayFragmentsList(*fragmentsList, fav);
