@@ -17,6 +17,7 @@
  **
  ****************************************************************************/
 #include "eacDlg.h"
+#include "deprecation.h"
 //#if defined (Q_WS_MAC) || defined (Q_OS_MAC)
 //#include <OpenGL/glu.h>
 // //#include <glu.h>
@@ -217,7 +218,7 @@ void EacGLW::draw(){
   //mol->nonPositiveDefinite=0;
 //  mol->parthigh=false;
   glPushMatrix();
-  glScaled( 50, 50, 50 );
+  glScaled( 40, 40, 40 );
   mol->adp=1;
   mol->intern=1;
   mol->tubes=0;
@@ -314,7 +315,11 @@ void EacGLW::initializeGL(){
   //g_program=mol->installShader();
 }
 void EacGLW::resizeGL(int width, int height){
-  glViewport(0, 0, width, height);        
+#if defined Q_OS_MAC && (QT_VERSION >= 0x050000)
+  glViewport(0, 0, width*2, height*2);
+#else  
+  glViewport(0, 0, width, height);
+#endif
   glGetIntegerv(GL_VIEWPORT, vp);
   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();
@@ -324,7 +329,11 @@ void EacGLW::resizeGL(int width, int height){
 void EacGLW::paintGL(){
   glClearColor(0.8f,0.8f,0.8f,1.0f);
   glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
+#if defined Q_OS_MAC && (QT_VERSION >= 0x050000)
+  glViewport(0, 0, QGLWidget::width()*2, QGLWidget::height()*2);        
+#else  
   glViewport(0, 0, QGLWidget::width(), QGLWidget::height());        
+#endif
   glGetIntegerv(GL_VIEWPORT, vp);
   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();
@@ -965,13 +974,13 @@ void EacDlg::hbdistChanged(double){
 }
 
 void EacDlg::updateHBElemnts(){
-    QStringList accst=accLE->text().simplified().split(",",QString::SkipEmptyParts);
+    QStringList accst=accLE->text().simplified().split(",",skipEmptyParts);
     mol->theseAreAcceptors.clear();
     for (int i=0; i<accst.size();i++){
         int an=mol->getOZ(accst.at(i));
         if (an>=0) mol->theseAreAcceptors.append(an);
     }
-    QStringList donst=donLE->text().simplified().split(",",QString::SkipEmptyParts);
+    QStringList donst=donLE->text().simplified().split(",",skipEmptyParts);
     mol->theseAreDonors.clear();
     for (int i=0; i<donst.size();i++){
         int an=mol->getOZ(donst.at(i));
