@@ -1,4 +1,5 @@
 #include "fcvsfo.h"
+#include "deprecation.h"
 
 FcVsFo::FcVsFo(QString filename,double a,double b, double c, double al, double be, double ga, double lambda){
   const double g2r=180.0/M_PI;
@@ -90,10 +91,10 @@ FcVsFo::FcVsFo(QString filename,double a,double b, double c, double al, double b
   txt2->moveBy(480,503); 
   txt2->setData(0,-1);
   QToolBar *tb=new QToolBar(this);
-  tb-> addAction(QIcon(":/icons/zoom-in.png"),"Zoom +",this,SLOT(zoomin())); 
-  tb-> addAction(QIcon(":/icons/zoom-out.png"),"Zoom -",this,SLOT(zoomout()));
-  tb-> addAction(QIcon(":/icons/zoom-fit.png"),"Zoom selected",this,SLOT(zoomfit()));
-  tb-> addAction(QIcon(":/icons/zoom-off.png"),"Zoom out",this,SLOT(zoomoff()));
+  tb-> addAction(QIcon(":/xle-icons/zoom-in.png"),"Zoom +",this,SLOT(zoomin()));
+  tb-> addAction(QIcon(":/xle-icons/zoom-out.png"),"Zoom -",this,SLOT(zoomout()));
+  tb-> addAction(QIcon(":/xle-icons/zoom-fit.png"),"Zoom selected",this,SLOT(zoomfit()));
+  tb-> addAction(QIcon(":/xle-icons/zoom-off.png"),"Zoom out",this,SLOT(zoomoff()));
   QComboBox *cbx=new QComboBox(this);
   cbx->addItem("Fo vs. Fc",1);
   cbx->addItem("Delta( F^2)/sigma vs. sin(theta/lambda)");
@@ -198,9 +199,9 @@ void FcVsFo::readFCF(){
 		  break;
 	  case 1:
 		  f.reset();
-		  lines=QString(f.readAll()).split(QRegExp("[\\r\\n]"),QString::SkipEmptyParts);
+		  lines=QString(f.readAll()).split(QRegExp("[\\r\\n]"),skipEmptyParts);
 		  for (int i=0; i<lines.size(); i++){
-		    tok=lines.at(i).split(' ',QString::SkipEmptyParts);
+		    tok=lines.at(i).split(' ',skipEmptyParts);
 		    if (!tok.isEmpty()){
 		      obs.h=cal.h=tok.at(1).toInt();
 		      obs.k=cal.k=tok.at(2).toInt();
@@ -226,14 +227,14 @@ void FcVsFo::readFCF(){
 		  break;
 	  case 3:{
 		   f.reset();
-		   lines=QString(f.readAll()).split(QRegExp("[\\r\\n]"),QString::SkipEmptyParts);
+		   lines=QString(f.readAll()).split(QRegExp("[\\r\\n]"),skipEmptyParts);
 
 		   int i= 0;
 		   for (int j=0; !j; i++){
 		     if (lines.at(i).contains("_refln_B_calc")) j++;
 		   }
 		   for (; i<lines.size(); i++){
-		     tok=lines.at(i).split(' ',QString::SkipEmptyParts);
+		     tok=lines.at(i).split(' ',skipEmptyParts);
 		     if (!tok.isEmpty()&&(tok.size()==7)){
 		       obs.h= cal.h=tok.at(0).toInt();
 		       obs.k= cal.k=tok.at(1).toInt();
@@ -262,14 +263,14 @@ void FcVsFo::readFCF(){
 		 break;
 	  case 4:{
 		   f.reset();
-		   lines=QString(f.readAll()).split(QRegExp("[\\r\\n]"),QString::SkipEmptyParts);
+		   lines=QString(f.readAll()).split(QRegExp("[\\r\\n]"),skipEmptyParts);
 
 		   int i= 0;
 		   for (int j=0; !j; i++){
 		     if (lines.at(i).contains("_refln_observed_status")) j++;
 		   }
 		   for (; i<lines.size(); i++){
-		     tok=lines.at(i).split(' ',QString::SkipEmptyParts);
+		     tok=lines.at(i).split(' ',skipEmptyParts);
 		     if (!tok.isEmpty()&&(tok.size()==7)){
 		       obs.h= cal.h=tok.at(0).toInt();
 		       obs.k= cal.k=tok.at(1).toInt();
@@ -296,9 +297,9 @@ void FcVsFo::readFCF(){
 		 //		 qDebug()<<"List4 OK";
 		 break;
 	  case 5:f.reset();
-		 lines=QString(f.readAll()).split(QRegExp("[\\r\\n]"),QString::SkipEmptyParts);
+		 lines=QString(f.readAll()).split(QRegExp("[\\r\\n]"),skipEmptyParts);
 		 for (int i=0; i<lines.size(); i++){
-		   tok=lines.at(i).split(' ',QString::SkipEmptyParts);
+		   tok=lines.at(i).split(' ',skipEmptyParts);
 		   if (!tok.isEmpty()&&(tok.size()>5)){
 		     obs.h=cal.h=tok.at(0).toInt();
 		     obs.k=cal.k=tok.at(1).toInt();
@@ -322,7 +323,7 @@ void FcVsFo::readFCF(){
 		 break;
 	  case 6:{
 		   f.reset();
-		   lines=QString(f.readAll()).split(QRegExp("[\\r\\n]"),QString::SkipEmptyParts);
+		   lines=QString(f.readAll()).split(QRegExp("[\\r\\n]"),skipEmptyParts);
 
 		   int i= 0;
 		   for (int j=0; (!j)&&(i<lines.size()); i++){
@@ -330,7 +331,7 @@ void FcVsFo::readFCF(){
 		   }
 		   // qDebug()<<i<<lines.at(i);
 		   for (; i<lines.size(); i++){
-		     tok=lines.at(i).split(' ',QString::SkipEmptyParts);
+		     tok=lines.at(i).split(' ',skipEmptyParts);
 		     if (!tok.isEmpty()&&(tok.size()==7)){
 		       obs.h= cal.h=tok.at(0).toInt();
 		       obs.k= cal.k=tok.at(1).toInt();
@@ -364,7 +365,7 @@ void FcVsFo::readFCF(){
 	  case 8:{
 
 		   f.reset();
-		   lines=QString(f.readAll()).split(QRegExp("[\\r\\n]"),QString::SkipEmptyParts);
+		   lines=QString(f.readAll()).split(QRegExp("[\\r\\n]"),skipEmptyParts);
 
 		   int i= 0;
 		   for (int j=0; (!j)&&(i<lines.size()); i++){
@@ -372,7 +373,7 @@ void FcVsFo::readFCF(){
 		   }
 //		    qDebug()<<i<<lines.at(i-1);
 		   for (; i<lines.size(); i++){
-		     tok=lines.at(i).split(' ',QString::SkipEmptyParts);
+		     tok=lines.at(i).split(' ',skipEmptyParts);
 		     if (!tok.isEmpty()&&(tok.size()==9)){
 		       obs.h= cal.h=tok.at(0).toInt();
 		       obs.k= cal.k=tok.at(1).toInt();
