@@ -23,12 +23,15 @@
 #include <math.h>
 #include <ctype.h>
 #include <string.h>
+#include <locale.h>
 //#include <fftw3.h> //if you want you can try to uncoment this, but then you have to coment the following line
 #include "kissfft/kiss_fftnd.h"
 #include "molecule.h"
 #include "chgl.h"
 #include <QObject>
 #include <QCheckBox>
+#include <QMutex>
+#include <QMutexLocker>
 
 //! Rec is a reflection type of a fcf 6 file.
 typedef struct {
@@ -92,7 +95,7 @@ class FourXle:public QObject{
     float f000;
     float overridef000;
     bool isBelo;
-    FourXle(Molecule *mole_, ChGL *chgl_,QToolBar *toolView, QProgressBar *bar,double resol=2.5, double wght=1.1);
+    FourXle(Molecule *mole_, ChGL *chgl_,QToolBar *toolView, double resol=2.5, double wght=1.1);
     /*!< @param mole_ pointer to the Molecule of ShelXle 
      *  @param chgl_ pointer to the ChGL widged of ShelXle
      *  @param toolView pointer to the View Toolbar of ShelXle
@@ -127,8 +130,6 @@ class FourXle:public QObject{
     float sigma[3];//!<sigma values 
     float iso[3];//!<iso values
     //  double mInimum[2],mAximum[2];
-    QProgressBar *balken;//!< a progress bar to make waiting more fun. 
-    int balkenstep;//!< steps for the progress bar 
     V3 urs;//!< origin
     double rr,//!< resolution factor (the higher the more grid points) 
            rw;//!< a parameter to downweight weak reflections
@@ -160,7 +161,8 @@ class FourXle:public QObject{
   Node *nodeX;
   Node *nodeY;
   Node *nodeZ;
-  void CalcPlaneVertex( int ix, int iy, int iz ,V3 n,V3 ap);
+  QCheckBox *extendUnit;
+  void CalcPlaneVertex( int ix, int iy, int iz ,V3 n,V3 ap,V3 off);
   void makeFacesp(int nn, Node poly[] );
   void MakeElementp( int ix, int iy, int iz ,int s1, int s2);
   int IndexSelectedP( Node& node0, Node& node1, Node& node2, Node& node3 );
@@ -168,9 +170,10 @@ class FourXle:public QObject{
   void makePlane(QList<V3> &lines,int a1, int a2, int a3);
   double min,max;
   V3 orig,test3;
+  V3 pnormal,aufpunkt;
   QLineEdit *contMapFile, *contourValueEdit, *contEPSFile;
-  QComboBox *aspectRatios, *centerIsOn;
-  QDoubleSpinBox *cScopeBx;
+  QComboBox *aspectRatios, *centerIsOn, *sourceMap;
+  QDoubleSpinBox *cScopeBx, *heightScale;
   inline double winkel(V3 a,V3 b){
     return acos((a.x*b.x+a.y*b.y+a.z*b.z)/(sqrt(a.x*a.x+a.y*a.y+a.z*a.z)*sqrt(b.x*b.x+b.y*b.y+b.z*b.z)));
   }
@@ -198,9 +201,10 @@ class FourXle:public QObject{
 signals:
     void bigmessage(const QString &);//!< to comunicate with the informaton window
     void reloadRes();
-    void progress(int v);
+    void haltMW();//stop the map worker
 
   private:
+    mutable QMutex mutex;
     double C[15],D[9],sy[12][192],wave;
     inline int Intersect( double& vm, double& vp ){ return vm*vp <= 0.0 && (vm<0.0 || vp<0.0); }
     inline int dex(int x,int y,int z);
@@ -232,7 +236,7 @@ signals:
     //    V3 CalcNormalZ( int ix, int iy, int iz );
     int IndexSelected( FNode& node0, FNode& node1, FNode& node2, FNode& node3);
     //    V3& VectorSelected( FNode& node0, FNode& node1, FNode& node2, FNode& node3);
-    void MakeElement( int ix, int iy, int iz ,int s1, int s2, int faps);
+    void MakeElement( int ix, int iy, int iz, int faps);
     void makeFaces(int n, int faps, FNode poly[] );
     char titl[80];/*fcmax=0,f000=0,resmax=99999.0,*/
     void trimm(char s[]);
@@ -270,8 +274,6 @@ class GenMapWorker : public QThread{
     Molecule *mole;
     bool neu;
     int imin,imax;
-signals:
-    void progress(int v);
 };
 
 
