@@ -18,6 +18,7 @@
 ****************************************************************************/
 #include "historywidget.h"
 #include <QtGui>
+#include "deprecation.h"
 //#define PROGRAM_NAME "shelXle"
 HistoryWidget::HistoryWidget(QWidget *parent) :
     QWidget(parent){
@@ -277,18 +278,18 @@ void HistoryWidget::setPath(QString dirName,int wid){
 
 
     //REM R1 =  0.0150 for   6927 Fo > 4sig(Fo)  and  0.0160 for all   7220 data
-    QStringList sl = inhalt.section("REM R1 =",1).section("\n",0,0).trimmed().split(" ",QString::SkipEmptyParts);
+    QStringList sl = inhalt.section("REM R1 =",1).section("\n",0,0).trimmed().split(" ",skipEmptyParts);
     if (sl.size()<11) continue;
     RWerte.append(sl.at(0).toDouble()*100.0);
     gooddata.append(sl.at(2).toInt());
     RallWerte.append(sl.at(7).toDouble()*100.0);
     alldata.append(sl.at(10).toInt());
     //R1(Free) =
-    QStringList slfree = inhalt.section("REM R1(Free) =",1).section("\n",0,0).trimmed().split(" ",QString::SkipEmptyParts);
+    QStringList slfree = inhalt.section("REM R1(Free) =",1).section("\n",0,0).trimmed().split(" ",skipEmptyParts);
     if (slfree.size()>1){
         FreeWerte[RWerte.size()-1]=slfree.at(0).toDouble()*100;
     }
-    sl = inhalt.section("REM R1 =",1).section("\n",1,1).trimmed().split(" ",QString::SkipEmptyParts);
+    sl = inhalt.section("REM R1 =",1).section("\n",1,1).trimmed().split(" ",skipEmptyParts);
     if (sl.size()<2) continue;
     parameters.append(sl.at(1).toInt());
     saveFilesList.append(alt.fileName());
@@ -305,20 +306,20 @@ void HistoryWidget::setPath(QString dirName,int wid){
 
       inhalt = inhalt.section("\nHKLF ",1);
       //REM R1 =  0.0150 for   6927 Fo > 4sig(Fo)  and  0.0160 for all   7220 data
-      QStringList sl = inhalt.section("REM R1 =",1).section("\n",0,0).trimmed().split(" ",QString::SkipEmptyParts);
+      QStringList sl = inhalt.section("REM R1 =",1).section("\n",0,0).trimmed().split(" ",skipEmptyParts);
       if (sl.size()<11) return;
       RWerte.append(sl.at(0).toDouble()*100.0);
       gooddata.append(sl.at(2).toInt());
       RallWerte.append(sl.at(7).toDouble()*100.0);
       alldata.append(sl.at(10).toInt());
       //R1(Free) =
-      QStringList slfree = inhalt.section("REM R1(Free) =",1).section("\n",0,0).trimmed().split(" ",QString::SkipEmptyParts);
+      QStringList slfree = inhalt.section("REM R1(Free) =",1).section("\n",0,0).trimmed().split(" ",skipEmptyParts);
       if (slfree.size()>1){
       FreeWerte[RWerte.size()-1]=slfree.at(0).toDouble()*100;
       }
 
 
-      sl = inhalt.section("REM R1 =",1).section("\n",1,1).trimmed().split(" ",QString::SkipEmptyParts);
+      sl = inhalt.section("REM R1 =",1).section("\n",1,1).trimmed().split(" ",skipEmptyParts);
       if (sl.size()<2) return;
       parameters.append(sl.at(1).toInt());
       saveFilesList.append(alt.fileName());
@@ -333,19 +334,19 @@ void HistoryWidget::setPath(QString dirName,int wid){
         inhalt = inhalt.section("\nHKLF ",1);
 	//REM R1 =  0.0150 for   6927 Fo > 4sig(Fo)  and  0.0160 for all   7220 data
 
-    QStringList sl = inhalt.section("REM R1 =",1).section("\n",0,0).trimmed().split(" ",QString::SkipEmptyParts);
+    QStringList sl = inhalt.section("REM R1 =",1).section("\n",0,0).trimmed().split(" ",skipEmptyParts);
 	if (sl.size()<11) return;
 	RWerte.append(sl.at(0).toDouble()*100.0);
 	gooddata.append(sl.at(2).toInt());
 	RallWerte.append(sl.at(7).toDouble()*100.0);
         alldata.append(sl.at(10).toInt());
         //R1(Free) =
-        QStringList slfree = inhalt.section("REM R1(Free) =",1).section("\n",0,0).trimmed().split(" ",QString::SkipEmptyParts);
+        QStringList slfree = inhalt.section("REM R1(Free) =",1).section("\n",0,0).trimmed().split(" ",skipEmptyParts);
         if (slfree.size()>1){
         FreeWerte[RWerte.size()-1]=slfree.at(0).toDouble()*100;
         }
 
-        sl = inhalt.section("REM R1 =",1).section("\n",1,1).trimmed().split(" ",QString::SkipEmptyParts);
+        sl = inhalt.section("REM R1 =",1).section("\n",1,1).trimmed().split(" ",skipEmptyParts);
 	if (sl.size()<2) return;
 	parameters.append(sl.at(1).toInt());
 	saveFilesList.append(alt.fileName());
@@ -356,7 +357,7 @@ void HistoryWidget::setPath(QString dirName,int wid){
       update();
 }
 
-QColor HistoryWidget::farbverlauf(double wrt){
+QColor HistoryWidget::rwert_farbverlauf(double wrt){
   int rot,gruen,blau,alpha;
   int lauf=0;
   const float farbe[6][4]={
@@ -404,21 +405,26 @@ void HistoryWidget::paintEvent(QPaintEvent *event){
   p.drawText(0,fh,width(),fh,Qt::AlignLeft,QString("Total size of history on disk: %1%2")
       .arg((gesamtGr/(1024*1024))?(double)gesamtGr/(1024*1024):(double)gesamtGr/1024,7,'f',1)
       .arg((gesamtGr/(1024*1024))?"MB":"kB"));
+  double hupro=0;
+  for (int i = 0; i < RWerte.size(); i++){
+      hupro=qMax(hupro,RWerte.at(i));
+  }
+  hupro=(2*hupro);
   for (int i = 0; i < RWerte.size(); i++){
     if (FreeWerte.contains(i)){
-      p.setBrush(QBrush(farbverlauf(FreeWerte.value(i)*3)));
-      p.drawRect(i*w+5,qMax((int)(h-(FreeWerte.value(i)/25*h))-1,0),w*0.95-5,qMin((int)(FreeWerte.value(i)/25*h),h-2));
+      p.setBrush(QBrush(rwert_farbverlauf(FreeWerte.value(i)*3)));
+      p.drawRect(i*w+5,qMax((int)(h-(FreeWerte.value(i)/hupro*h))-1,0),w*0.95-5,qMin((int)(FreeWerte.value(i)/hupro*h),h-2));
     }
-    p.setBrush(QBrush(farbverlauf(RWerte.at(i)*3)));
-    p.drawRect(i*w,qMax((int)(h-(RWerte.at(i)/25*h))-1,0),w*0.9,qMin((int)(RWerte.at(i)/25*h),h-2));
+    p.setBrush(QBrush(rwert_farbverlauf(RWerte.at(i)*3)));
+    p.drawRect(i*w,qMax((int)(h-(RWerte.at(i)/hupro*h))-1,0),w*0.9,qMin((int)(RWerte.at(i)/hupro*h),h-2));
     if (FreeWerte.contains(i)){
-      p.drawText(i*w, qMax((int)(h-(FreeWerte.value(i)/25*h)),fh+5)-fh-2, w,fh,Qt::AlignLeft, QString("%1")
+      p.drawText(i*w, qMax((int)(h-(FreeWerte.value(i)/hupro*h)),fh+5)-fh-2, w,fh,Qt::AlignLeft, QString("%1")
           .arg(RWerte.at(i),4,'f',2));
 
-      p.drawText(i*w, qMax((int)(h-((FreeWerte.value(i))/25*h))-fh,fh+5)-fh-2, w,fh,Qt::AlignLeft, QString("%1")
+      p.drawText(i*w, qMax((int)(h-((FreeWerte.value(i))/hupro*h))-fh,fh+5)-fh-2, w,fh,Qt::AlignLeft, QString("%1")
           .arg(FreeWerte.value(i),4,'f',2));
     }else
-      p.drawText(i*w, qMax((int)(h-(RWerte.at(i)/25*h)),fh+5)-fh-2, w,fh,Qt::AlignLeft, QString("%1")
+      p.drawText(i*w, qMax((int)(h-(RWerte.at(i)/hupro*h)),fh+5)-fh-2, w,fh,Qt::AlignLeft, QString("%1")
           .arg(RWerte.at(i),4,'f',2));
   }
   event->accept();
