@@ -47,6 +47,7 @@ public:
     QStringList saveFilesList;//!< File name list of previous versions 
     QList<QDateTime> dateTimesList;//!< List of file dates
     void setPath(QString dirName, int width);//!< sets the path to the resfile and the history sub directory.
+    QColor rwert_farbverlauf(double wrt);
 signals:
     void message(const QString &);//!< emitts a text to the status bar
     void lofi(const QString &);//!< load a file version 
@@ -64,7 +65,6 @@ protected:
 //  void wheelEvent ( QWheelEvent * event );
 private:
   size_t gesamtGr;
-  QColor farbverlauf(double wrt);
   int maxwid;
   int fh;//font height
   QString dirname;
