@@ -46,9 +46,9 @@ void IdealDefdenGenerator::beloWriteCube(){
   bu.clear();
   double midd=9.9e37,madd=-9.9e37,rho,summ=0.0,sum1=0.0, sum2=0.0;
   QList<Matrix> mi;
-  const double pisqrt = sqrt(M_PI);
+  //const double pisqrt = sqrt(M_PI);
   const double pi2=M_PI*M_PI;
-  const double pisqrt3=M_PI*pisqrt;
+  //const double pisqrt3=M_PI*pisqrt;
   Matrix M,Mi;
   double d;
   for (int i=0; i<belo.size(); i++){
@@ -80,8 +80,7 @@ void IdealDefdenGenerator::beloWriteCube(){
     }
     aproc = (pro * 100) / ntot;
     if (aproc!=bproc){
-        emit message(QString("Calculating deformation density %1% (steps:%2)").arg(aproc).arg(ntot));        
-        emit progress(aproc);
+        emit message(QString("Calculating deformation density %1% (steps:%2)").arg(aproc).arg(ntot));
         bproc = aproc;
     }    
   }
