@@ -26,8 +26,7 @@ Q_OBJECT
   QObject *mommy;//parent
   FourXle *fxle;
 
-signals:  
-  void progress(int v);
+signals:
   void message(const QString &);//!< small text messages to the status bar.
 };
 #endif
