@@ -9,7 +9,7 @@ class IncludeEditor : public QDialog
 {
     Q_OBJECT
 public:
-    explicit IncludeEditor(QString inclstr, const QString &_dir, QWidget *parent = NULL  , Qt::WindowFlags f = 0);
+    explicit IncludeEditor(QString inclstr, const QString &_dir, QWidget *parent = NULL);
     QPushButton * ok;//!> the ok button
     void setDirName(const QString &_dir);
 signals:
