@@ -1,6 +1,7 @@
 #include "listfile.h"
 #include <QtCore>
 #include <QTextStream>
+#include "deprecation.h"
 
 /*
  * This file handles the ShelXl lst file during and after the refinement
@@ -80,7 +81,7 @@ QVector<QStringList> ListFileHandler::listfileparser() {
   int num = 0;
   foreach(QString line, *listfcontent) {
     QStringList splitline;
-    splitline = line.split(" ", QString::SkipEmptyParts);
+    splitline = line.split(" ", skipEmptyParts);
     if (splitline.isEmpty()) {
       continue;
     }
@@ -287,7 +288,7 @@ QString ListFileHandler::thetaFromLst() {
   QString theta = "";
   foreach(QString line, *listfcontent) {
     if (line.contains("Max. 2-theta")) {
-      theta = line.section("theta", 1, 1).split(" ", QString::SkipEmptyParts).at(1);
+      theta = line.section("theta", 1, 1).split(" ", skipEmptyParts).at(1);
     }
   }
   return theta;
@@ -658,7 +659,7 @@ QString XLOutputParser::xl_version(QString line) {
   QString version;
   QStringList linesplit;
   if (line.contains(versionregex)) {
-    linesplit = line.split(" ", QString::SkipEmptyParts);
+    linesplit = line.split(" ", skipEmptyParts);
     int index = linesplit.indexOf("Version");
     version = linesplit.at(index+1);
   }
@@ -674,7 +675,7 @@ QStringList XLOutputParser::xl_threads(QString line) {
   QStringList linesplit;
   QRegExp tprocregex = QRegExp("Running\\s+\\d\\s+threads\\s+on\\s+\\d\\s+processors");
   if (line.contains(tprocregex)) {
-    linesplit = line.split(" ", QString::SkipEmptyParts);
+    linesplit = line.split(" ", skipEmptyParts);
     threads = linesplit.at(1);
     processors = linesplit.at(4);
   }
@@ -706,8 +707,8 @@ QStringList XLOutputParser::xl_current_wr2_data_param(QString line) {
   QString all_parameters = "";
   QStringList alldata;
   if (line.contains("wR2") && line.contains("cycle") && line.contains("data")
-      && (line.split(" ", QString::SkipEmptyParts).size() >= 12) ) {
-    linesplit = line.split(" ", QString::SkipEmptyParts);
+      && (line.split(" ", skipEmptyParts).size() >= 12) ) {
+    linesplit = line.split(" ", skipEmptyParts);
     wr2 = linesplit.at(2);
     cycle = linesplit.at(5);
     data = linesplit.at(7);
@@ -733,7 +734,7 @@ QStringList XLOutputParser::xl_rint_rsigma(QString line) {
   QStringList linesplit, rvals;
   QString l=line.remove('=');
   if (line.contains("R(sigma)")) {
-    linesplit = l.split(" ", QString::SkipEmptyParts);
+    linesplit = l.split(" ", skipEmptyParts);
     int RintInd = linesplit.indexOf(QRegExp("R\\(int\\)"));
     if ((RintInd != -1) && linesplit.length() > RintInd+1) {//>= leads to segmentation fault
       rint = linesplit.at(RintInd+1);
@@ -759,8 +760,8 @@ QStringList XLOutputParser::xl_current_goof(QString line) {
   QStringList linesplit;
   QStringList goofs;
   if (line.contains("Restrained GooF") && line.contains("restraints")
-      && (line.split(" ", QString::SkipEmptyParts).size() >= 8)) {
-    linesplit = line.split(" ", QString::SkipEmptyParts);
+      && (line.split(" ", skipEmptyParts).size() >= 8)) {
+    linesplit = line.split(" ", skipEmptyParts);
     goof = linesplit.at(4);
     goof.remove(QChar(';'));
     rgoof = linesplit.at(8);
@@ -779,8 +780,8 @@ QStringList XLOutputParser::xl_final_goofs(QString line) {
   QString rgoof;
   QStringList linesplit;
   QStringList goofs;
-  if (line.contains("for all data") && (line.split(" ", QString::SkipEmptyParts).size() >= 11) ) {
-    linesplit = line.split(" ", QString::SkipEmptyParts);
+  if (line.contains("for all data") && (line.split(" ", skipEmptyParts).size() >= 11) ) {
+    linesplit = line.split(" ", skipEmptyParts);
     goof = linesplit.at(7);
     goof.remove(QChar(','));
     rgoof = linesplit.at(11);
@@ -800,12 +801,12 @@ QStringList XLOutputParser::xl_current_meanshift_esd(QString line) {
   QString max_esd_shiftfor = "";
   QStringList linesplit;
   if (line.contains("shift/esd") && line.contains("Maximum")
-      && (line.split(" ", QString::SkipEmptyParts).size() >= 6) ) {
-    linesplit = line.split(" ", QString::SkipEmptyParts);
+      && (line.split(" ", skipEmptyParts).size() >= 6) ) {
+    linesplit = line.split(" ", skipEmptyParts);
     meanshift = linesplit.at(3);
     maxshift_esd = linesplit.at(6);
-    max_esd_shiftfor = line.split("for", QString::SkipEmptyParts).at(1).trimmed()
-        .split("at", QString::SkipEmptyParts).at(0).trimmed();
+    max_esd_shiftfor = line.split("for", skipEmptyParts).at(1).trimmed()
+        .split("at", skipEmptyParts).at(0).trimmed();
   }
   shifts.append(meanshift);
   shifts.append(maxshift_esd);
@@ -825,11 +826,11 @@ QStringList XLOutputParser::xl_current_max_shift(QString line) {
   QStringList linesplit;
   QStringList shifts;
   if (line.contains("Max. shift") && line.contains("dU") && line.contains("for")
-      && (line.split(" ", QString::SkipEmptyParts).size() >= 6) ) {
-    linesplit = line.split(" ", QString::SkipEmptyParts);
+      && (line.split(" ", skipEmptyParts).size() >= 6) ) {
+    linesplit = line.split(" ", skipEmptyParts);
     maxshift = linesplit.at(3);
     maxshiftfor = linesplit.at(6);
-    dU = line.split("dU").at(1).trimmed().remove("=").split(" ", QString::SkipEmptyParts).at(0);
+    dU = line.split("dU").at(1).trimmed().remove("=").split(" ", skipEmptyParts).at(0);
     dUfor = line.split("for").at(2).trimmed();
   }
   shifts.append(maxshift);
@@ -868,7 +869,7 @@ QString XLOutputParser::xl_final_R1_4sig(QString line) {
   QString r1_4sigma = "";
   QStringList linesplit;
   if (line.contains("R1") && line.contains("4sig") && line.contains("for all")) {
-    linesplit = line.split(" ", QString::SkipEmptyParts);
+    linesplit = line.split(" ", skipEmptyParts);
     r1_4sigma = linesplit.at(2);
     r1_4sigma.remove(QChar(','));
   }
@@ -880,7 +881,7 @@ QString XLOutputParser::xl_final_R1all(QString line) {
   QString r1all = "";
   QStringList linesplit;
   if (line.contains("R1") && line.contains("merging for Fourier") && line.contains("for")) {
-    linesplit = line.split(" ", QString::SkipEmptyParts);
+    linesplit = line.split(" ", skipEmptyParts);
     r1all = linesplit.at(2);
     r1all.remove(QChar(','));
   }
@@ -892,7 +893,7 @@ QString XLOutputParser::xl_final_wR2(QString line) {
   QString finalwr2;
   QStringList linesplit;
   if (line.contains("wR2") && line.contains("for all data")) {
-    linesplit = line.split(" ", QString::SkipEmptyParts);
+    linesplit = line.split(" ", skipEmptyParts);
     finalwr2 = linesplit.at(2);
     finalwr2.remove(QChar(','));
   }
@@ -909,8 +910,8 @@ QStringList XLOutputParser::xl_peak(QString line) {
   QString from = "";
   QStringList linesplit;
   if (line.contains("Highest peak") && line.contains("from")
-      && (line.split(" ", QString::SkipEmptyParts).size() >= 6) ) {
-    linesplit = line.split(" ", QString::SkipEmptyParts);
+      && (line.split(" ", skipEmptyParts).size() >= 6) ) {
+    linesplit = line.split(" ", skipEmptyParts);
     peak = linesplit.at(2);
     coord = linesplit.at(4)+" "+linesplit.at(5)+" "+linesplit.at(6);
     dist = line.split("[").at(1).split("]").at(0).trimmed().split(" ").at(0);
@@ -933,8 +934,8 @@ QStringList XLOutputParser::xl_hole(QString line) {
   QString from = "";
   QStringList linesplit;
   if (line.contains("Deepest hole") && line.contains("from")
-      && (line.split(" ", QString::SkipEmptyParts).size() >= 12) ) {
-    linesplit = line.split(" ", QString::SkipEmptyParts);
+      && (line.split(" ", skipEmptyParts).size() >= 12) ) {
+    linesplit = line.split(" ", skipEmptyParts);
     hole = linesplit.at(2);
     coord = linesplit.at(4)+" "+linesplit.at(5)+" "+linesplit.at(6);
     dist = line.split("[").at(1).split("]").at(0).trimmed().split(" ").at(0);
@@ -956,13 +957,13 @@ QStringList XLOutputParser::xl_flacksvals(QString line) {
   QStringList linesplit;
   if (line.contains("Flack x") && line.contains("classical fit")
       && (!line.contains("No quotients"))
-      && (line.split(" ", QString::SkipEmptyParts).size() >= 3) ) {
-    linesplit = line.split(" ", QString::SkipEmptyParts);
+      && (line.split(" ", skipEmptyParts).size() >= 3) ) {
+    linesplit = line.split(" ", skipEmptyParts);
     flack = linesplit.at(3);
   }
   if (line.contains("Flack x") && line.contains("Parsons' method")
-      && (line.split(" ", QString::SkipEmptyParts).size() >= 3) ) {
-    linesplit = line.split(" ", QString::SkipEmptyParts);
+      && (line.split(" ", skipEmptyParts).size() >= 3) ) {
+    linesplit = line.split(" ", skipEmptyParts);
     parson = linesplit.at(3);
 
   }
@@ -977,7 +978,7 @@ QString XLOutputParser::xl_timeval(QString line) {
   QStringList linesplit;
   QString time = "";
   if (line.contains("finished") && line.contains("time")) {
-    linesplit = line.split(" ", QString::SkipEmptyParts);
+    linesplit = line.split(" ", skipEmptyParts);
     time = linesplit.at(linesplit.indexOf("time:")+1);
   }
   return time;
