@@ -45,31 +45,31 @@ void mh(QtMsgType type, const QMessageLogContext &context, const QString &msg) {
     case QtDebugMsg:
       fprintf(stderr, "Debug: %s (%s:%u, %s)\n", localMsg.constData(), context.file, context.line, context.function);
 // Q_WS_* was droppen in QT5 in favor of Q_OS_*
-#if defined Q_WS_WIN  ||  defined Q_WS_MAC || defined Q_OS_WIN || defined Q_OS_MAC
+#if defined Q_WS_WIN  ||  defined Q_OS_WIN 
     QMessageBox::information(0,"information",msg);
 #endif
       break;
     case QtInfoMsg:
       fprintf(stderr, "Info: %s (%s:%u, %s)\n", localMsg.constData(), context.file, context.line, context.function);
-#if defined Q_WS_WIN  ||  defined Q_WS_MAC || defined Q_OS_WIN || defined Q_OS_MAC
+#if defined Q_WS_WIN  ||  defined Q_OS_WIN 
     QMessageBox::information(0,"information",msg);
 #endif
       break;
     case QtWarningMsg:
       fprintf(stderr, "Warning: %s (%s:%u, %s)\n", localMsg.constData(), context.file, context.line, context.function);
-#if defined Q_WS_WIN  ||  defined Q_WS_MAC || defined Q_OS_WIN || defined Q_OS_MAC
+#if defined Q_WS_WIN  ||  defined Q_OS_WIN 
     QMessageBox::warning(0,"warning",msg);
 #endif
       break;
     case QtCriticalMsg:
       fprintf(stderr, "Critical: %s (%s:%u, %s)\n", localMsg.constData(), context.file, context.line, context.function);
-#if defined Q_WS_WIN  || defined Q_WS_MAC || defined Q_OS_WIN || defined Q_OS_MAC
+#if defined Q_WS_WIN  || defined Q_OS_WIN 
     QMessageBox::critical(0,"critical",msg);
 #endif
       break;
     case QtFatalMsg:
       fprintf(stderr, "Fatal: %s (%s:%u, %s)\n", localMsg.constData(), context.file, context.line, context.function);
-#if defined Q_WS_WIN  || defined Q_WS_MAC || defined Q_OS_WIN || defined Q_OS_MAC
+#if defined Q_WS_WIN  || defined Q_OS_WIN 
     QMessageBox::critical(0,"fatal",msg);
 #endif
       abort();
@@ -99,25 +99,25 @@ void mh(QtMsgType type, const char *msg){
 
     printf("%s\n",msg);fflush(stdout);
 
-#if defined Q_WS_WIN  ||  defined Q_WS_MAC
+#if defined Q_WS_WIN  
     QMessageBox::information(0,"information",msg);
 #endif
     break;
   case QtWarningMsg:
     printf("%s\n",msg);fflush(stdout);
-#if defined Q_WS_WIN  ||  defined Q_WS_MAC
+#if defined Q_WS_WIN  
     QMessageBox::warning(0,"warning",msg);
 #endif
     break;
   case QtCriticalMsg:
     printf("%s\n",msg);fflush(stdout);
-#if defined Q_WS_WIN  || defined Q_WS_MAC
+#if defined Q_WS_WIN  
     QMessageBox::critical(0,"critical",msg);
 #endif
     break;
   case QtFatalMsg:
     printf("%s\n",msg);fflush(stdout);
-#if defined Q_WS_WIN  || defined Q_WS_MAC
+#if defined Q_WS_WIN  
     QMessageBox::critical(0,"fatal",msg);
 #endif
     abort();
@@ -130,8 +130,8 @@ void printicon(){
 #if defined Q_WS_WIN  ||   defined Q_OS_WIN
 #define DEFINE_CONSOLEV2_PROPERTIES
 #endif
-  QImage II=QImage(":/icons/SHELxLE.png" );
-//  QImage II=QPixmap(":/icons/cbh.png" ).toImage();
+  QImage II=QImage(":xle-icons/SHELxLE.png" );
+//  QImage II=QPixmap(":xle-icons/cbh.png" ).toImage();
   int r, g, b, c216,gray,k=0;
   double alpha;
   char x[9]="@ShelXle";
@@ -170,20 +170,18 @@ int main(int argv, char *args[]){
   QApplication app(argv, args);
   
   app.setOrganizationName("shelxle");
-  app.setWindowIcon(QIcon(":/icons/SHELxLE.png"));
+  app.setWindowIcon(QIcon(":xle-icons/SHELxLE.png"));
   //printicon();
 #if (QT_VERSION >= 0x050000)
   qInstallMessageHandler(mh);
 #else
   qInstallMsgHandler(mh);
-#endif
-
-
+#endif 
   Window *window = new Window();
   window->show();
   int istat = app.exec();
-  printf("delete the main window now...\n");
+  //printf("delete the main window now...\n");
   delete window;
-  printf("%d bye bye! Thanks for using!\n",istat);
+  //printf("%d bye bye! Thanks for using!\n",istat);
   return istat;
 }
