@@ -24,14 +24,14 @@ PSEWidget::PSEWidget(QWidget *parent) :
     selection=0;
     mole.loadSettings();
 //#define PROGRAM_NAME "shelXle"
-    mole.einstellung = new QSettings( QSettings::IniFormat, QSettings::UserScope ,PROGRAM_NAME,PROGRAM_NAME ,this);
+    mole.einstellung = new QSettings( QSettings::IniFormat, QSettings::UserScope ,PROGRAM_NAME,mole.mynewnameis ,this);
     sz=mole.pseFontSize;
     QToolButton *TB;
     lplus = new QToolButton();
-    lplus->setIcon(QIcon(":/icons/efplus.png"));
+    lplus->setIcon(QIcon(":/xle-icons/efplus.png"));
     connect(lplus,SIGNAL(pressed()),this,SLOT(incFontSize()));
     lminus = new QToolButton();
-    lminus->setIcon(QIcon(":/icons/efminus.png"));
+    lminus->setIcon(QIcon(":/xle-icons/efminus.png"));
     lplus->setStyleSheet(
                 QString(
                 "QToolButton { /* all types of tool button */\n"
@@ -83,7 +83,7 @@ PSEWidget::PSEWidget(QWidget *parent) :
     connect(lminus,SIGNAL(pressed()),this,SLOT(decFontSize()));
 
 
-/*    a=viewMenu->addAction(QIcon(":/icons/laminus.png"),
+/*    a=viewMenu->addAction(QIcon(":/xle-icons/laminus.png"),
 		    tr("decrease label fontsize"),chgl,SLOT(decFontSize()),
 		    QKeySequence("Alt+-"));*/
     esm = new QSignalMapper(this);
@@ -100,6 +100,7 @@ PSEWidget::PSEWidget(QWidget *parent) :
         if (i<107)TB->setStyleSheet(
                 QString(
                 "QToolButton { /* all types of tool button */\n"
+                "color: #000000;\n"
                 "border: 1px solid #8f8f91;"
                 "border-radius: 2px;"
                 "background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,"
