@@ -1,22 +1,31 @@
 #include "savehistorywidget.h"
+#include "deprecation.h"
 
-SaveHistoryWidget::SaveHistoryWidget(QString filename, QWidget *parent  , Qt::WindowFlags f ):QDialog(parent,f){
+SaveHistoryWidget::SaveHistoryWidget(QString filename, bool _dark, QWidget *parent  ):QDialog(parent){
   pvindex=-1;
   fileName=filename;
-  dda = new DragDropVersions(filename,parent);
+  dark=_dark;
+  dda = new DragDropVersions(filename,dark,parent);
   QScrollArea *qsa = new QScrollArea();
   qsa->setWidget(dda);
   QScrollArea *preview = new QScrollArea();
   QVBoxLayout *pvla = new QVBoxLayout();
   pvheader = new QLabel("<h3>current file version</h3>"); 
+  if (dark){
+  pvheader->setStyleSheet (QString(
+        "QLabel{font: bold; border: 2px solid #2f2f31; border-radius: 1px;background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,stop: 0 #007700, stop: 1 #424242);} "
+        "QLabel:hover {background-color: qlineargradient(x1: 0, y1: 0, x2: 1, y2: 0," "stop: 0 #242424, stop: 1 #007700);border: 2px solid #eeeeee;}"));
+  }else{
   pvheader->setStyleSheet (QString(
         "QLabel{font: bold; border: 2px solid #2f2f31; border-radius: 1px;background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,stop: 0 #aaeeaa, stop: 1 #dadbde);} "
         "QLabel:hover {background-color: qlineargradient(x1: 0, y1: 0, x2: 1, y2: 0," "stop: 0 #ffffff, stop: 1 #aaee00);border: 2px solid #eeeeee;}"));
-  edi = new CodeEditor(); 
-  QString inspatternfile=":ins_res_style.ini";
+  }
+  edi = new CodeEditor();
+  edi->dark=dark;
+  QString inspatternfile=(dark)?":ins_res_style_dark.ini":":ins_res_style.ini";
   edi->highlighter->loadHighlightPatterns(inspatternfile);
   QFont font;
-  font.setFamily("Monospace");
+  font.setFamily(FONTFAM);
   font.setFixedPitch(true);
   font.setPointSize(9);
   edi->setFont(font);
@@ -57,11 +66,19 @@ SaveHistoryWidget::SaveHistoryWidget(QString filename, QWidget *parent  , Qt::Wi
 void SaveHistoryWidget::updatePreview(int index){
   if ((index>=0)&&(index<dda->zeiten.size())) {
     DragVersion *childle = static_cast<DragVersion *>(sender());
-    if (childle)
+    if (childle){
+        if (dark){
+            childle->setStyleSheet (QString(
+                  "QLabel{color: #ffffff; font: bold; border: 2px solid #2f2f31; border-radius: 1px;background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,stop: 0 %1, stop: 1 #242424);} "
+                  "QLabel:hover {background-color: qlineargradient(x1: 0, y1: 0, x2: 1, y2: 0,"
+                  "stop: 0 #424242, stop: 1 %1);border: 0px solid #eeeeee;;}").arg("#007700"));
+        } else {
       childle->setStyleSheet (QString(
             "QLabel{font: bold; border: 2px solid #2f2f31; border-radius: 1px;background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,stop: 0 %1, stop: 1 #dadbde);} "
             "QLabel:hover {background-color: qlineargradient(x1: 0, y1: 0, x2: 1, y2: 0,"
-            "stop: 0 #ffffff, stop: 1 %1);border: 0px solid #eeeeee;;}").arg(QColor("#aaeeaa").name()));
+            "stop: 0 #ffffff, stop: 1 %1);border: 0px solid #eeeeee;;}").arg("#00eeaa"));
+        }
+    }
     pvheader->setText(QString("<h3>%1</h3>").arg(dda->zeiten.at(index).toString()));
     pvindex=index;
     edi->setReadOnly(false);
@@ -115,53 +132,8 @@ void SaveHistoryWidget::accept(){
   }
   done(QDialog::Accepted);
 }
-/*
-QString DragDropVersions::seit(int wann){
-  / *! turns seconds into a human readable QString Example: 1 days 12 hours 24 minutes 36 seconds ago
-    \param wann seconds elapsed. Negative values lie in the furure. 
-    \returns Human readable time elapsed (long version).
-    * / 
-  QString dann;
-  int i = abs(wann);
-  int d = i / 86400;
-  dann = (d)?((d==1)?"1 day ":QString("%1 days ").arg(d)):" ";
-  int h = (i - d*86400)/3600;
-  dann += (h)?((h==1)?"1 hour ":QString("%1 hours ").arg(h)):" ";
-  int m = ((i - d*86400)-(h*3600))/60;
-  dann += (m)?((m==1)?"1 minute ":QString("%1 minutes ").arg(m)):" ";
- // int s = ((i - d*86400)-(h*3600)-(m*60));
- // dann += (s)?((s==1)?"1 second ":QString("%1 seconds ").arg(s)):" ";
-  // printf("%d d%d h%d m%d s%d \n ", i,d,h,m,s);
 
-  if (wann <0 ) dann+=" ago";
-  else if (wann == 0 ) dann+="now";
-  else dann.prepend("in ");
-  return dann.simplified();
-}
-
-QString DragDropVersions::seitkurzem(int wann){
-  / *! turns seconds into a human readable QString Example: 1d 12h 24m 36s ago
-    \param wann seconds elapsed. Negative values lie in the furure. 
-    \returns Human readable time elapsed (short version). 
-    * /
-  QString dann;
-  int i = abs(wann);
-  int d = i / 86400;
-  dann = (i>=86400)?(QString("%1d ").arg(d)):" ";
-  int h = (i - d*86400)/3600;
-  dann += (i>=3600)?(QString("%1h ").arg(h,2,10,QChar('0'))):" ";
-  int m = ((i - d*86400)-(h*3600))/60;
-  dann += (i>=60)?(QString("%1m ").arg(m,2,10,QChar('0'))):" ";
-  int s = ((i - d*86400)-(h*3600)-(m*60));
-  dann += QString("%1s ").arg(s,2,10,QChar('0'));
-
-  if (wann <0 ) dann+=" ago";
-  else if (wann == 0 ) dann+="now";
-  else dann.prepend("in ");
-  return dann.simplified();
-}
-*/
-DragDropVersions::DragDropVersions(QString filename, QWidget *parent) :QWidget(parent){
+DragDropVersions::DragDropVersions(QString filename, bool d,QWidget *parent) :QWidget(parent){
   /*! 
    *  Gets the directory of filename and 
    *  loads in the subdirectory "PROGRAM_NAME"saves (usualy shelXlesaves/) the file SAVEHIST.
@@ -175,7 +147,7 @@ DragDropVersions::DragDropVersions(QString filename, QWidget *parent) :QWidget(p
   QString insorres=argument;
   if (insorres.endsWith("res",Qt::CaseInsensitive)) insorres.replace(QRegExp("res$",Qt::CaseInsensitive),"ins");
   else if (insorres.endsWith("ins",Qt::CaseInsensitive)) insorres.replace(QRegExp("ins$",Qt::CaseInsensitive),"res");
-
+  dark=d;
   current=-1;
   QString saveHistName=QString("%1/%2saves/SAVEHIST").arg(dn).arg(PROGRAM_NAME);
   QFile sahi(saveHistName);
@@ -183,7 +155,7 @@ DragDropVersions::DragDropVersions(QString filename, QWidget *parent) :QWidget(p
   QString Alles=sahi.readAll();//Entry|@|2011-03-08T13:32:19|@|b11.res|@|
   sahi.close();
   QRegExp re = QRegExp("Entry\\|@\\|\\w+-\\w+-\\w+:\\w+:\\w+\\|@\\|[^@]+@\\|");
-  entries = Alles.split(re,QString::SkipEmptyParts);
+  entries = Alles.split(re,skipEmptyParts);
   int pos = re.indexIn(Alles);
   QStringList filenames;
   while (pos>-1) {
@@ -205,15 +177,15 @@ DragDropVersions::DragDropVersions(QString filename, QWidget *parent) :QWidget(p
   int y = 5;
   int row=0,lawi=0,ymax=0;
   DragVersion * l;
-
-  l =new DragVersion(-1,"current file version",666,-1,this);
+  uint beast=666;
+  l =new DragVersion(-1,QString("current file version"),beast, -1, dark, this);
   l->move(5, 5);
   l->show();
   breite = lawi = itemwidth=l->width()+25;
   hoehe = l->height()+25;
   x=lawi+5;
   for (int i=0; i<zeiten.size(); i++){
-    DragVersion *wordLabel = new DragVersion(i,zeiten.at(i).toString(),zeiten.at(i).toTime_t(),-1 , this);
+    DragVersion *wordLabel = new DragVersion(i,zeiten.at(i).toString(),zeiten.at(i).toTime_t(),-1,dark , this);
     wordLabel->move(x, y);
     wordLabel->show();
     wordLabel->setAttribute(Qt::WA_DeleteOnClose);
@@ -242,7 +214,7 @@ DragDropVersions::DragDropVersions(QString filename, QWidget *parent) :QWidget(p
 
 void DragDropVersions::paintEvent(QPaintEvent *event){
   QPainter p(this);
-  p.fillRect(event->rect(), QColor("#eeeeee"));
+  p.fillRect(event->rect(), (dark)?QColor("#455364"):QColor("#eeeeee"));
   p.fillRect(0, 0, breite, hoehe, QColor("#aac0cc"));
 }
 
@@ -254,7 +226,11 @@ void DragDropVersions::tack(){
     if (!child||!child->inherits("QLabel")) continue;
     int idx=child->index();
     if ((idx==-1)&&(child->secs()==666)) {
-      child->setStyleSheet (QString(
+        if (dark)child->setStyleSheet (QString(
+                          "QLabel{color: #ffffff; font: bold; border: 2px solid #2f2f31; border-radius: 1px;background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,stop: 0 %1, stop: 1 #242424);} "
+                          "QLabel:hover {background-color: qlineargradient(x1: 0, y1: 0, x2: 1, y2: 0,"
+                          "stop: 0 #424242, stop: 1 %1);border: 0px solid #eeeeee;;}").arg((idx==current)?"#007799":"#007700"));
+        else child->setStyleSheet (QString(
             "QLabel{font: bold; border: 2px solid #2f2f31; border-radius: 1px;background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,stop: 0 %1, stop: 1 #dadbde);} "
             "QLabel:hover {background-color: qlineargradient(x1: 0, y1: 0, x2: 1, y2: 0,"
             "stop: 0 #ffffff, stop: 1 %1);border: 2px solid #eeeeee;}").arg(QColor((idx==current)?"#aaeeaa":"#ffeecc").name()));
@@ -262,7 +238,11 @@ void DragDropVersions::tack(){
     if ((idx<0)||(idx>=zeiten.size())||(child->secs()==666)) continue;
     //child->setText(seitkurzem(now.secsTo(QDateTime::fromTime_t (child->secs()))));
     child->setText(QDateTime::fromTime_t (child->secs()).toString());
-    child->setStyleSheet (QString(
+    if (dark)child->setStyleSheet (QString(
+                      "QLabel{color: #ffffff; font: bold; border: 2px solid #2f2f31; border-radius: 1px;background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,stop: 0 %1, stop: 1 #242424);} "
+                      "QLabel:hover {background-color: qlineargradient(x1: 0, y1: 0, x2: 1, y2: 0,"
+                      "stop: 0 #424242, stop: 1 %1);border: 0px solid #eeeeee;;}").arg((idx==current)?"#007799":"#007700"));
+    else child->setStyleSheet (QString(
           "QLabel{font: bold; border: 2px solid #2f2f31; border-radius: 1px;background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,stop: 0 %1, stop: 1 #dadbde);} "
           "QLabel:hover {background-color: qlineargradient(x1: 0, y1: 0, x2: 1, y2: 0,"
           "stop: 0 #ffffff, stop: 1 %1);border: 2px solid #eeeeee;}").arg(QColor((idx==current)?"#aaeeaa":"#ffeecc").name()));
@@ -279,15 +259,23 @@ void DragDropVersions::mousePressEvent(QMouseEvent *event){
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-DragVersion::DragVersion(const int index,const QString &text, uint secs,const int cur, QWidget *parent): QLabel(parent){
+DragVersion::DragVersion(const int index,const QString &text, uint secs,const int cur, bool d, QWidget *parent): QLabel(parent){
   m_labelText = text;
   m_index = index;
   m_secs = secs;
+  dark=d;
   setText(m_labelText);
+  if (dark){
+  setStyleSheet (QString(
+        "QLabel{color: #ffffff; font: bold; border: 2px solid #2f2f31; border-radius: 1px;background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,stop: 0 %1, stop: 1 #242424);} "
+        "QLabel:hover {background-color: qlineargradient(x1: 0, y1: 0, x2: 1, y2: 0,"
+        "stop: 0 #424242, stop: 1 %1);border: 0px solid #eeeeee;;}").arg((index==cur)?"#007799":"#007700"));
+}else{
   setStyleSheet (QString(
         "QLabel{font: bold; border: 2px solid #2f2f31; border-radius: 1px;background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,stop: 0 %1, stop: 1 #dadbde);} "
         "QLabel:hover {background-color: qlineargradient(x1: 0, y1: 0, x2: 1, y2: 0,"
         "stop: 0 #ffffff, stop: 1 %1);border: 2px solid #eeeeee;}").arg(QColor((index==cur)?"#aaeeaa":"#ffeecc").name()));
+  }
 }
 
 QString DragVersion::labelText() const{
