@@ -9,11 +9,12 @@
 //! DragVersion is a QLabel that represents an earlier version of a res file and shows the time elapsed since it was saved. Used in SaveHistoryWidget
 class DragVersion  : public QLabel {
 public:
-        DragVersion(const int index,const QString &text, uint secs,const int cur, QWidget *parent=0);
+        DragVersion(const int index,const QString &text, uint secs,const int cur, bool d, QWidget *parent=0);
 	
         QString labelText() const;//!< \returns the DragVersion text.
         int index() const;//!< \returns positional index
         uint secs() const;//!< \returns seconds elapsed since it was created
+        bool dark;
 //protected:
 //	void paintEvent ( QPaintEvent * event ) ;
 
@@ -29,12 +30,13 @@ class SaveHistoryWidget;
 class DragDropVersions : public QWidget {
 Q_OBJECT
 public:
-         DragDropVersions(QString filename, QWidget *parent = 0);
+         DragDropVersions(QString filename, bool d,QWidget *parent = 0);
 //	 QString seit(int wann);
 //	 QString seitkurzem(int wann);
          QDateTime now;//!< now is the the current QDateTime.
-	 QTimer *tick;//!< tick is a QTime creating ticks every second.
-         friend class SaveHistoryWidget;
+         QTimer *tick;//!< tick is a QTime creating ticks every second.
+         bool dark;
+         friend class SaveHistoryWidget;        
 signals:
 	 void indexChanged(int index);//!< When a DragVersion is clicked the version viewed changes 
 public slots:
@@ -56,8 +58,9 @@ protected:
 class SaveHistoryWidget : public QDialog {
 Q_OBJECT
 public:
-    SaveHistoryWidget(QString filename, QWidget *parent = 0, Qt::WindowFlags f = 0);
+    SaveHistoryWidget(QString filename, bool _dark, QWidget *parent = 0);
     QPushButton * ok;//!> the ok button 
+    bool dark;
 //signals:
 public slots:
 	void tock();
