@@ -130,7 +130,7 @@ class Scatt{
     f000=0.0;
     Fmax=0.0;
     resd=-1.0f;
-    printf("Scatt(Molecule *m) %f\n",resd);
+    //printf("Scatt(Molecule *m) %f\n",resd);
     //   qDebug()<<"12345"<<atomformfactor(12,0.0);
   }
 
@@ -351,7 +351,7 @@ class Scatt{
   QString myfcf(QString fn){
     //  qDebug()<<mol->hklf;
     //  qDebug()<<mol->hklScale<<mol->hklSigmaScale;
-    if ((mol->hklf<3)&&(mol->hklf>4)) return "";
+    if ((mol->hklf<3)||(mol->hklf>4)) return "";
     //  const float twopi=M_PI*2.0;
     const float twopi2=M_PIf*M_PIf*2.0f;
     QTime zeit; zeit.start();
@@ -423,11 +423,11 @@ class Scatt{
 
     //  printf("wave:%f %f %f %f %d %d wl=%d\n",mol->cell.wave,fabs(mol->cell.wave-0.71073),fabs(mol->cell.wave-1.5418),fabs(mol->cell.wave-0.56083), mol->cell.ns0, mol->cell.symmops.size(),wl);
 
-    printf("hklf N=%d s:%g \n%g %g %g\n%g %g %g\n%g %g %g\nsm: %g \n",mol->hklf,mol->hklScale ,
+    /*printf("hklf N=%d s:%g \n%g %g %g\n%g %g %g\n%g %g %g\nsm: %g \n",mol->hklf,mol->hklScale ,
         mol->hklMat.m11,mol->hklMat.m12,mol->hklMat.m13,
         mol->hklMat.m21,mol->hklMat.m22,mol->hklMat.m23,
         mol->hklMat.m31,mol->hklMat.m32,mol->hklMat.m33,
-        mol->hklSigmaScale);
+        mol->hklSigmaScale);*/
     while (!feof(hkl)){    
       if (fgets(line,120,hkl)) {;}
       if (feof(hkl))continue;
@@ -542,18 +542,12 @@ class Scatt{
       lr[i].fc=0.0;
       lr[i].fc=FF(chkl,wl,lr[i].phi,lr[i].dis);
       lr[i].fo =lr[i].fo * (lr[i].fc*lr[i].fc/lr[i].dis);//correct for dispersion
-      if (lr[i].dis<=-665.0) {
+      if (lr[i].dis<=-665.0f) {
         lr[i].fc=0.0;
         continue;
       }
       if ((mol->exti!=-666.0)&&(mol->swat==-666.0)){
-        float _s=(sintl2(chkl)*0.25);
-        float _t=_s*mol->cell.wave*mol->cell.wave;
-        //float _x=0.0005*mol->cell.wave*mol->cell.wave*mol->cell.wave*ob.dis/sqrt(_t*(1.0-_t));
-        float _x=0.0005*mol->cell.wave*mol->cell.wave*mol->cell.wave*lr[i].fc*lr[i].fc/sqrt(_t*(1.0-_t));
-        float __t=sqrt(1.+_x*mol->exti);
-        lr[i].fo*=__t;
-        lr[i].si*=__t;
+        lr[i].fc*=pow(1 + 0.001 * mol->exti * lr[i].fc * lr[i].fc  *mol->cell.wave * mol->cell.wave /sqrt(sintl2(chkl)),-0.25);
       }
       float xx=lr[i].fc*lr[i].fc;
       float yy=lr[i].fo*lr[i].fo;
@@ -576,8 +570,8 @@ class Scatt{
     resd=0.5f/sqrtf(resd);
     printf("???? %f \n",resd);
     fprintf(fc6,
-        "#\n# h,k,l, Fo-squared, sigma(Fo-squared), Fc and phi(calc)\n#\ndata_%s\n_shelx_title '%s'\n_shelx_refln_list_code          6\n\
-        _shelx_F_calc_maximum      %6.2f\n_exptl_crystal_F_000       %6.2f\n_reflns_d_resolution_high  %6.4f\n\nloop_\n_space_group_symop_operation_xyz\n"
+        "#\n# h,k,l, Fo-squared, sigma(Fo-squared), Fc and phi(calc)\n#\ndata_%s\n_shelx_title '%s'\n_shelx_refln_list_code          6\n"
+        "_shelx_F_calc_maximum      %6.2f\n_exptl_crystal_F_000       %6.2f\n_reflns_d_resolution_high  %6.4f\n\nloop_\n_space_group_symop_operation_xyz\n"
         ,base.toStdString().c_str()
         ,mol->titl.toStdString().c_str()
         ,Fmax
@@ -587,8 +581,8 @@ class Scatt{
     for (int s=0; s<mol->cell.symmops.size();s++) 
       fprintf(fc6,"'%s'\n",mol->symmcode2human(s).trimmed().toStdString().c_str());
     fprintf(fc6,
-        "\n_cell_length_a   %8.4f\n_cell_length_b   %8.4f\n_cell_length_c   %8.4f\n_cell_angle_alpha %7.3f\n_cell_angle_beta  %7.3f\n_cell_angle_gamma %7.3f\n\n\
-        loop_\n_refln_index_h\n_refln_index_k\n_refln_index_l\n_refln_F_squared_meas\n_refln_F_squared_sigma\n_refln_F_calc\n_refln_phase_calc\n",
+        "\n_cell_length_a   %8.4f\n_cell_length_b   %8.4f\n_cell_length_c   %8.4f\n_cell_angle_alpha %7.3f\n_cell_angle_beta  %7.3f\n_cell_angle_gamma %7.3f\n\n"
+        "loop_\n_refln_index_h\n_refln_index_k\n_refln_index_l\n_refln_F_squared_meas\n_refln_F_squared_sigma\n_refln_F_calc\n_refln_phase_calc\n",
         mol->cell.a,mol->cell.b,mol->cell.c,mol->cell.al,mol->cell.be,mol->cell.ga
         );
     int igut=0;
