@@ -18,6 +18,7 @@
  ****************************************************************************/
 #ifndef WINDOW_H
 #define WINDOW_H
+#include <locale.h>
 #include <QtGui>
 #include <QtNetwork>
 #include "chgl.h"
@@ -49,6 +50,17 @@
 #else
 #define std_isfinite std::isfinite
 #endif
+
+#ifndef FONTFAM
+#if defined Q_WS_WIN || defined Q_OS_WIN
+#define FONTFAM "Droid Sans Mono"
+#elif defined Q_WS_MAC || defined Q_OS_MAC
+#define FONTFAM "Monaco"
+#else
+#define FONTFAM "Droid Sans Mono"
+#endif
+#endif
+
 #include "calculator.h"
 #include "dsrgui.h"
 #include "listfile.h"
@@ -65,6 +77,7 @@ class Window : public QMainWindow {
     virtual ~Window();
     //bool scroller;
     static int Version();//!< This return the actual Revision
+    bool restraintsOrConstraints();
     int MaxNumberOfPeaks;
     static QString programName(){return QString(PROGRAM_NAME);}//!<get the actual programname
     ChGL *chgl;  
@@ -74,6 +87,7 @@ class Window : public QMainWindow {
     QAction *showQPeakLegend;
     QAction *openAct; 
     QAction *screenshotAct;
+    QAction *objExport;
     QAction *tubeStyle;
     QAction *ballStyle;
     QAction *separateLabelFile;
@@ -102,6 +116,7 @@ class Window : public QMainWindow {
     QAction *togElli;
     QAction *togHBond;
     QAction *togBackGr;
+    QAction *togDepthCueing;
     QAction *killQs;
     QAction *killHs;
     QAction *astdlg;
@@ -111,13 +126,17 @@ class Window : public QMainWindow {
     QAction *recalcSDM;
     QAction *renamUpdateAct;
     QAction *cntrPlot;
+    QAction *useNativeDlg;
+    QAction *darkTheme;
     QTextBrowser *brs;
     QProcess *runffmpeg;
     QLineEdit *ffmpegedt,*mp4file;
     QString fffn;
     QLabel *ffl;
+    QString oldFileName;
     QProgressBar *bar;
     QPushButton  *closeFF ;
+    QDialog *extraOutput;
 
     QToolBar *editToolBar,//!< Edit toolbar (redo undo copy cut and paste...) 
              *refineToolBar,//!< WGHTrefine, autoHFIX, +kill Hs, kill Qs, refine XL and anis refine 
@@ -135,12 +154,17 @@ class Window : public QMainWindow {
     QToolButton  *zoomIn;
     QToolButton  *zoomOut;
     QToolButton  *homeMe;
+    QToolButton *quickReLoadButton;
+    QCheckBox *sr_same;
+    QCheckBox *sr_simu;
+    QCheckBox *sr_rigu;
     bool notRefine;
     int tbiconSize;
     QHash<QString,QVariant> myHash;//!< This Hash connects recent file names with cursor positions. So that files are opened always at the same position.
     QAction *refineAct;
     QAction *refineActAnis;
     QAction *refineActActa;
+    QAction *clearVoro;
     FourXle *fxle;//!<The fourier map object.
     //  QList<V3> orte;
     //  QList<V3> normalen,nnn;
@@ -151,19 +175,25 @@ class Window : public QMainWindow {
     QMap<int,int> fvarCntr;//!<Free Variable counter QMap.
     bool isLabelInUse();//!< Checks if the current Label in the reaname dialog is in use. \returns true if Label is already in use.
     QString dirName; //!< Full path of the currently opened file (including file name).
+    QString actionInfo;
     void setFocus(bool b){focusSet=b;}
     bool isFocusSet() {return focusSet;}
     int getFvarCntr(int fvar);//!< returns the number of uses of a free variable.
     int firstAtomLine;
+    int extraIndex;
     bool finWasPressed;
+    QAction *ydleStart;
+    QAction *ydleStop;
+    QSpinBox *lpart;
+    QSpinBox *rpart;
 
 signals:
     void fileLoaded(void);
     void pipeStatus(const QString& s);  //!<changes the statusbar text to s @param s text for the status bar
+    void movedByUser();
 
     public slots:
       void qinitres();
-    void about();//!<Shows the about dialog of ShelXle.
     void addNewScatteringFactor(int oz);//!<Adds a new scattering factor to the SFAC / UNIT list.
     void addDissorderedMethyl();//!<Adds rotation dissordered hydroghen atoms to a R-C carbon atom. (methyl group) AFIX 127.
     void addMethyl();//!<Adds hydroghen atoms to a R-C carbon atom. (methyl group) AFIX 137.
@@ -177,7 +207,7 @@ signals:
     void addMoreQPeaks();//!<Creates Q-Peaks from the Fo-Fc map.
     void adoptEditToolBar(bool b);//editToolbar is child of shxMW or the MainWindow
     void aula();//!< Auto Labeling
-    void autoHFix();//!<Automatically adds H atoms and AFIX instructions to the file uses the Fo-Fc map. 
+    void autoHFix();//!<Automatically adds H atoms and AFIX instructions to the file uses the Fo-Fc map.
     void brwsIcon();//!< Select an alternative icon for external program
     void changeFixes(int i);//!< Variable that should not be refined get a 10 added.
     void changeEditorFont();//!<Changes the Editor font via an font dialog.
@@ -193,8 +223,9 @@ signals:
     void checkForUpdates();//!<Checks via the internet if new versions of ShelXle are availabe.
     void clipboardDataChanged();//!<Enables the paste action if something is in the clipboard.
     void clearStructure();
-    void closeEvent(QCloseEvent *event);//!<Tidys everything up and stores settings befor closing the ShelXle app.
+    void closeEvent(QCloseEvent *event);//!<Tidys everything up and stores settings before closing the ShelXle app.
     void configBeLos();//!< Configure BEDE LONE Objects style
+    void darkEdit();
     void brwsEPS();
     void everyPointOne();
     void everyAIM();
@@ -216,8 +247,11 @@ signals:
     void effuenf();//!<F5 recalculates the display lists sets the focus to the openGL widget and raises it on top. 
     void expandAll();//!<Expands all contacts .
     void extraSettings();//!<A dialog to add/edit exteral programs started from ShelXle with or without arguments.
-    void exportCoordinates();//!<Exports all visible atoms to an extra file. 
+    void extraSettingsLast();//!<A dialog to add/edit exteral programs started from ShelXle with or without arguments.
+    void exportCoordinates();//!<Exports all visible atoms to an extra file.     
+    void exportCC();//!< Export coordinates to computational chemistry program inputs like Gaussian or Turbomol
     void exportFMaps();
+    void fileNative();
     bool fileSave(bool spell=true, bool loadafter=true);//!<saves the editor content to the current file. @param spell disable spell checking during save @param loadafter disable reloading of file.
     bool fileSaveAs();//!<Saves the editor content to a specified file.
     void fillCell();//!<Uses symmetry until the unit cell box is full.
@@ -233,11 +267,17 @@ signals:
     void grossRC(const QString &text);//!< Capitalizes the text and sets the resiResiClass text to text @param text new text for resiResiClass.
     void grow();//!< completes the molecule by symmetry.
     void growQPeaks(bool qpg);//!< applies symmetrie operations used for the main structure also for the Q-Peaks.
+    void hereAreMyKeys();
     void hideToolz(bool b);//!< Hides all tool bars.
     void hintLhide();//!< Hides a hint in the reaname mode for ever.
+    void idleRotStart();
+    void idleRotStop();
+    void incResiNr();
+    void decResiNr();
     void infoKanalNews(const QString& s);//!< passes a string to the Info widget. @param s a new text for the info widget.
     void inheritLabels();//!< opens an inherit labels dialog.
     void insertSADI(int selected); //!< Insert SADI restraint into ins file
+    void insertTwin();
     void invert();//!< inverts the structure and changes ot the right enantiomorph space group.
     //  inline int Intersect( double& vm, double& vp ){ return vm*vp <= 0.0 && (vm<0.0 || vp<0.0); }//!<
     void isUpToDate(QNetworkReply* antwort);//!< Interpretes the network reply for the check for updates (manual version)
@@ -247,13 +287,17 @@ signals:
     void loadAFile();//!< (re)loads the file specified in dirName.
     void loadFile(QString fileName);//!< loads the file with the specified path the listfile is also loaded. @param fileName path to the res / ins file.
     void load_sheldrick(QString fileName, QString &inhalt);//!< Loads a shelx file from a string. You have to take care that the file is valid beforehand.
+    bool quickReLoad(QString fn, QString &cont);//!< Updates a structure after refinement or save With keeping grow and hide states unchanged. If differences are to large false is returned 1/19/2021
     void loadLst();//!< loads the .lst file if it exists.
     void loadrefres();//!< loads the refinement results from the res file.
     void loadThisFile();//!< loads a file from an QAction with path as Action data. 
 
     void makeVoro();
+    void clearVoros();
     void moveSymmMate();//!< Moves the specified symmetry generated atom to the asymmetric unit.
     void moveSymmMateSel();//!< Moves selected symmetry generated atoms to the asymmetric unit.
+    void obj();
+    void omitRfl();
     void openFile();//!< Open res file dialog
     void openRecentFile();//!< opens a recently used file
     void openSaveHistory();//!< sows the save history dialog
@@ -270,7 +314,7 @@ signals:
     void rename2ThisAtom(int index);//!< tries to find an apropriate H label
     void renamUpdate(bool vis);//!<rename mode gets shown or hidden. @param vis visibitity of rename mode.
     void replyFinished(QNetworkReply* antwort);//!<Interpretes the network reply for the check for updates (automatic version)
-    void resiSelectorCheck();//!<updates the 'Residue Finder' when the text cursor moves.
+    void resiSelectorCheck();//!<updates the 'Residue Finder' when the text cursor moves.    
     void rotd();//!< rotates down 
     void rotl();//!< rotates left   
     void rotr();//!< rotates right   
@@ -280,6 +324,8 @@ signals:
     void runExtra();//!< runs rexternal programs
     void runXLWGHT();//!< runs shelxl for convergeWght. 
     void saveScene();//!< saves a srceen shot of the OpenGL widget
+    void savePovRay();
+    void savePovInc(QString povName);
     void sdm();//!< the shortest distance matrix is (re)calculated and the structure is grown
     void selectInStructure(const QString &info);//!< selects all atoms found in selected text in the structure @params info seleted text. 
     void shredCIF();//!< runs shredcif and loads ins/res file
@@ -288,6 +334,8 @@ signals:
     void setShelxlPath();//!< sets path for ShelXl executable
     void setExtraPath();//!<sets path for an external program
     void setDefaultPath();//!<when the first recent file does not exists then open dialog starts here
+    void selOmitG5();
+    void selOmitG10();
     void updateExtraIcon();//!< redraws the icon preview
     void setSDMLimit();//!< max atoms in au to skip sdm calculation
     void setMonoQ(bool vis);//!<sets monochome modus for Q-Peaks to vis @param vis mochrome mode of Q-Peaks.
@@ -296,12 +344,17 @@ signals:
     void sina();//!< ANIS backwards is SINA! makes specified, selected or all atoms isotrop again with uiso = 0.05
     //  void springSlider();
     void  spellCheck();//!< a syntax check for the res file.
+    void closeSR(bool vis);
+    void splitRotate();
     QString strippedName(const QString &fullFileName);//!< the file name without the path is retrned \returns the filename without path. @param total file path. 
     void styleDialog();//!< Atom style dialog is shown.
-    void symmetryManager();//!< a symmetry manager is shown 
+    void symmetryManager();//!< a symmetry manager is shown
+    void testMerohedral();
     void toggDocWid(bool weg);//!< hides Text Windows
     void toggleEQHighlighting(bool);//!< toggles higlighting of symmetry generated atoms.
     void toggleFullScreen();
+    void toggleHFSAO(bool on);
+    void togOMIT(bool b);
     void toggleOrtho(bool ov);//!< toggles orthographic and perspective projection.
     void undoRename();//!<if undo is clicked and it was a rename a rename is undone.
     void uniq();//!< moves centers of gravity of all molecules into the unit cell box. !does not heal scrambled molecules!
@@ -316,16 +369,20 @@ signals:
     void updateSM3(const QUrl link);//!< for the symmetry manager dialog
     void updateSM4(QString s);//!< for the symmetry manager dialog
     void updateStatusBar(const QString& s) ;  //!<changes the statusbar text to s @param s text for the status bar
-    void updateTieFreeVar();//!< if the occupation factor should be tied to a free variable the rename mode 
+    void updateTieFreeVar();//!< if the occupancy factor should be tied to a free variable the rename mode
+    void updateTwinTest();
     void updateXLput();//!< the output view for the shelxl run is updated
     void updateExtraOutput();//!< the output view for the external program is updated.
     void updateExtraSettings(int index);//!< the external programs dialog gets updated.
     void updateExtraSettings();//!< the external programs dialog gets updated.  
     void wasDelete();//!< for undo redo fuctionality of atom deletion.
+    void worstReflections();
     void setFFMPEGEXE();
     void setMP4();
     void updateOutput();
     void makeRotMovi();
+    void split();
+    void notsplit();
     void wasRename();//!< for undo redo fuctionality of atom renameing. 
     void withdrawres();//!< discard the results of the refinement. Copies back the ins file to the res file and loads that.  
     void zoomin(); //!< zoomes in 
@@ -333,8 +390,8 @@ signals:
     void calculator(); //!< A dialog to work with resolution and 1,3 distances via the angle
     void create_DSRGui(); //!< A dialog for DSR
     void insertDSRLine(QString dsrline, int position, QVector<int> previousLine);
-    void aboutDSR(); //!<Shows the about dialog of the DSR GUI.  
     void dsrClosed();
+    void aboutXLE();//!<Shows the about dialog of ShelXle.
     CEnvironment lonesome(QString s,int startNummer);//!< calculates LONE objects  
     void beloWriteCube();//bello braf!
     static int isacommand(QString command);
@@ -350,12 +407,11 @@ signals:
     bool fullscreen;
     int wght_cycls; //!< Number of cycles during the wght refinement.
     int ls_cycls;   //!< Number of least-squares cycles during L.S. or CGLS refinement.
-    int SDM_Limit; //!< if the number of atoms in the au exceeds this limit shortest distance is not computed automatically default 350
     bool nowaste;// start labeling always at 1
     QNetworkAccessManager *net;
     QNetworkReply *reply;
     V3 urs;
-    QString altText;
+    QString altText,popel;//popel is original line of old rotation center rotze
     PSEWidget *psew;  
     QSpinBox *symmIntBx;
     QSpinBox *symmXBx;
@@ -368,12 +424,12 @@ signals:
     QLabel *shortestDistanceLabel;
     QPushButton *willpse;
     QPushButton *beloColorButton;
+
     bool machPlatz,FehlerTeufel;
     int hhh;
     //  QSlider *zoomer;
     //  QTimer *sliderTimer;
     QSignalMapper *dsm;
-    QProgressBar *balken;
     HistoryWidget *hw;
     double range,weight;
     int falschAtom;
@@ -401,7 +457,7 @@ signals:
     QPeakView *qpv;
     CEnvironment undoAtom,redoAtom,deletedAtom,restoredAtom;
     QList<int> undoAtomIndex,redoAtomIndex,gehtMichAn,gehtMichAn2;
-    int balkenstep,altursize;
+    int altursize;
     int mode;
     QMenu *recentFilesMenu,*stereoMenu,*moveMenu,*helpMenu,*sortMenu;
     QActionGroup *stereoGroup,*tubeGroup,*sortGroup;
@@ -420,7 +476,6 @@ signals:
     double scalePic;
     QString saveName,fvarinfo;
     QProcess *shelxl,*extraProc;
-    QDialog *extraOutput;
     QTextEdit *extraOutPut;
     CodeEditor *editor , *xlPutor;
     QString shelxlPath, shelxlArgs;
@@ -456,6 +511,7 @@ signals:
     QLabel *sLabel, *fvused;
     QCheckBox *qGrowPeak,*search4duplicates;
     QTimer *hidwillpse;
+
     QLabel *indexL,*sufixL;
     QLabel *scalwla, *scalhla, *scalsla, *header;
     QDialogButtonBox *buttonBoxRN; 
@@ -495,13 +551,24 @@ signals:
     void shx_editor(QString filename);//16.10.2019: title is class glabal variable. no need to give it as parameter her
     double getNumber(double v,const QList<double> fv,double uiso);//to be changed!
     double getNumber(double v,const QList<double> fv,int idx,int &fixFlag);//to be changed!
-    double ueq(Matrix m);
     MyAtom findOH(V3 donor, V3 acceptor,int dindex,QStringList alab);
     bool maybeSave();  
     bool maybeSave2();
     bool startFused;
     Calculator *calcmenu;
     DSRGui *dsr;
+    QString pngName;//output file of povray export
+    QScrollArea *qsaPNG ;
+
+    QList<bool> twinRedundant;
+    QList<bool> twinDone;
+    QDialog *twinDlg;
+    double rvalue2beat, wr2value2beat;
+    QVBoxLayout *twinvbl;
+    QGroupBox *twingpx;
+    QLabel *twinpatlab;
+    //QGroupBox *gpx =new QGroupBox("Posible twin laws for this structure:",twinDlg);
+    //QVBoxLayout *vbl = new QVBoxLayout();
     //QString selectedRestraintsAtoms(QString buffer, QList<MyAtom> selected, QString resiSpec, bool exclude_H=false);
 
 };
